"use strict";

var _nock = _interopRequireDefault(require("nock"));

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _error = require("../../service/error");

var _keys = _interopRequireDefault(require("./keys"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const apiKey = 'MXpvUUhSUFliZ28zSkdsak15WWhPZW1jZHZublhh';
const secretKey = 'RG1VNUFvYlVycTlQbUtjVmVXR3hBVzR5Wnc5VEZi';
const url = 'http://api.manage.keys.test';
const MOCK_KEYS = {
  api_private_key: secretKey,
  api_public_key: apiKey
};

const fakeAccountKeys = _sinon.fake.returns(JSON.stringify(MOCK_KEYS));

_ava.default.before(() => {
  (0, _nock.default)(url).get('/api/v1/account-keys/').basicAuth({
    user: 'username',
    pass: Buffer.from('password').toString('base64')
  }).reply(200, fakeAccountKeys, {
    'Content-Type': 'application/json'
  }).get('/api/v1/account-keys/').reply(401, 'You shall not pass', {
    'Content-Type': 'text/plain'
  });
});

(0, _ava.default)('get()', async t => {
  const {
    get
  } = (0, _keys.default)({
    url
  });
  t.deepEqual((await get({
    username: 'username',
    password: 'password'
  })), {
    apiKey,
    secretKey
  });
});
(0, _ava.default)('get() - 401', async t => {
  const {
    get
  } = (0, _keys.default)({
    url
  });
  const error = await t.throwsAsync(get({
    username: 'notauser',
    password: 'hacker'
  }), _error.ServiceError);
  t.is(error.code, 401);
  t.is(error.message, 'You shall not pass');
});