"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.into = into;
exports.gqConsoleProfile = gqConsoleProfile;
exports.profile = profile;

/**
 * A description of your profile.
 */

/**
 * Parameters passed in for updating your profile.
 */

/**
 * Manage your user’s profile.
 */
function fullName(firstName, lastName) {
  if (!firstName) {
    return lastName;
  }

  if (!lastName) {
    return firstName;
  }

  return `${firstName} ${lastName}`;
}

function into(user) {
  return {
    created: new Date(user.date_joined),
    department: {
      id: user.reseller_id,
      name: user.reseller_name,
      uuid: user.cs_domain_id || null
    },
    departmentAdmin: user.reseller_rights && user.reseller_rights.reduce((reduced, role) => {
      if (reduced.every(({
        id
      }) => id !== role.id)) {
        reduced.push({
          id: role.id,
          name: role.name,
          uuid: role.domain_id || null
        });
      }

      return reduced;
    }, []) || [],
    email: user.email,
    enabled: user.status.toLowerCase() === 'enabled',
    id: user.id,
    isSuperAdmin: user.is_superuser,
    name: fullName(user.first_name, user.last_name).trim() || user.username,
    projectOnly: user.disable_personal_account === true,
    projects: user.projects,
    status: user.status.toLowerCase(),
    username: user.username,
    uuid: user.uuid,
    verified: user.is_verified === true
  };
}

function gqConsoleProfile(call) {
  async function get() {
    const {
      objects: [user]
    } = await call('GET', 'account');
    return into(user);
  }

  async function update({
    email,
    name
  }) {
    const {
      id,
      name: oldName
    } = await get();
    const data = {
      email,
      full_name: name
    };

    if (typeof data.full_name === 'undefined') {
      data.full_name = oldName;
    }

    await call('PUT', `account/${id}`, {
      data
    });
    return get();
  }

  return {
    get,
    update
  };
}

function profile(call) {
  async function get() {
    const {
      objects: [user]
    } = await call('GET', 'account');
    return into(user);
  }

  async function update({
    email,
    name
  }) {
    const {
      id,
      name: oldName
    } = await get();
    const data = {
      email,
      full_name: name
    };

    if (typeof data.full_name === 'undefined') {
      data.full_name = oldName;
    }

    await call('PUT', `accounts/${id}`, {
      data
    });
    return get();
  }

  return {
    get,
    update
  };
}