"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _profile = require("./profile");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const MOCK_PROFILE = {
  cs_domain_id: '0000-de00-4000-a000-000000000001',
  date_joined: '1920-01-10T12:00:00-0200',
  disable_personal_account: false,
  email: 'testuser@example.com',
  first_name: 'Tester Örn',
  id: 2,
  is_superuser: false,
  is_verified: false,
  last_name: 'Testason',
  projects: [{
    id: 5,
    name: 'project5'
  }, {
    id: 42,
    name: 'computing-the-answer'
  }],
  reseller_id: 1,
  reseller_name: 'ROOT',
  reseller_rights: [{
    id: 8,
    domain_id: '0000-de00-4000-a000-000000000008',
    name: 'test-department'
  }],
  status: 'ENABLED',
  username: 'testuser',
  uuid: '00000000-0500-4000-a000-000000000002'
};
(0, _ava.default)('get()', async t => {
  const {
    get
  } = (0, _profile.profile)(_sinon.fake.resolves({
    objects: [MOCK_PROFILE]
  }));
  t.deepEqual((await get()), {
    created: new Date('1920-01-10T12:00:00-0200'),
    department: {
      id: 1,
      name: 'ROOT',
      uuid: '0000-de00-4000-a000-000000000001'
    },
    departmentAdmin: [{
      id: 8,
      name: 'test-department',
      uuid: '0000-de00-4000-a000-000000000008'
    }],
    email: 'testuser@example.com',
    enabled: true,
    id: 2,
    isSuperAdmin: false,
    name: 'Tester Örn Testason',
    projectOnly: false,
    projects: [{
      id: 5,
      name: 'project5'
    }, {
      id: 42,
      name: 'computing-the-answer'
    }],
    status: 'enabled',
    username: 'testuser',
    verified: false,
    uuid: '00000000-0500-4000-a000-000000000002'
  });
});
(0, _ava.default)('get() name defaults to username', async t => {
  const {
    get
  } = (0, _profile.profile)(_sinon.fake.resolves({
    objects: [{ ...MOCK_PROFILE,
      first_name: '',
      last_name: ''
    }]
  }));
  t.is((await get()).name, 'testuser');
});
(0, _ava.default)('get() name can handle last name only', async t => {
  const {
    get
  } = (0, _profile.profile)(_sinon.fake.resolves({
    objects: [{ ...MOCK_PROFILE,
      first_name: '',
      last_name: ' Örn Testason'
    }]
  }));
  t.is((await get()).name, 'Örn Testason');
});
(0, _ava.default)('get() name can handle first name only', async t => {
  const {
    get
  } = (0, _profile.profile)(_sinon.fake.resolves({
    objects: [{ ...MOCK_PROFILE,
      first_name: 'Tester',
      last_name: ''
    }]
  }));
  t.is((await get()).name, 'Tester');
});
(0, _ava.default)('get() has no duplicate departmentAdmins', async t => {
  const {
    get
  } = (0, _profile.profile)(_sinon.fake.resolves({
    objects: [{ ...MOCK_PROFILE,
      reseller_rights: [MOCK_PROFILE.reseller_rights[0], {
        id: 1,
        domain_id: '0000-de00-4000-a000-000000000001',
        name: 'ROOT'
      }, MOCK_PROFILE.reseller_rights[0]],
      is_superuser: true
    }]
  }));
  const {
    departmentAdmin,
    isSuperAdmin
  } = await get();
  t.true(isSuperAdmin);
  t.deepEqual(departmentAdmin.sort((a, b) => a.id - b.id), [{
    id: 1,
    name: 'ROOT',
    uuid: '0000-de00-4000-a000-000000000001'
  }, {
    id: 8,
    name: 'test-department',
    uuid: '0000-de00-4000-a000-000000000008'
  }]);
});
(0, _ava.default)('get() can handle non-cloudstack environment', async t => {
  const {
    get
  } = (0, _profile.profile)(_sinon.fake.resolves({
    objects: [{ ...MOCK_PROFILE,
      cs_domain_id: undefined,
      reseller_rights: [{
        id: 8,
        name: 'test-department'
      }]
    }]
  }));
  const {
    department,
    departmentAdmin
  } = await get();
  t.deepEqual(department, {
    id: 1,
    name: 'ROOT',
    uuid: null
  });
  t.deepEqual(departmentAdmin, [{
    id: 8,
    name: 'test-department',
    uuid: null
  }]);
});
(0, _ava.default)('gq-console-update()', async t => {
  const clone = { ...MOCK_PROFILE
  };

  function call(method, command, {
    data
  } = {}) {
    if (method === 'GET' && command === 'account') {
      return Promise.resolve({
        objects: [clone]
      });
    }

    if (method === 'PUT' && command === `account/${MOCK_PROFILE.id}`) {
      if (data.email) {
        clone.email = data.email;
      }

      if (data.full_name) {
        clone.first_name = data.full_name;
        clone.last_name = '';
      }

      return Promise.resolve('irrelevant');
    }

    throw new Error('unreachable');
  }

  const {
    update
  } = (0, _profile.gqConsoleProfile)(call);
  t.deepEqual((await update({
    email: 'new@example.com',
    name: 'New Name'
  })), {
    created: new Date('1920-01-10T12:00:00-0200'),
    department: {
      id: 1,
      name: 'ROOT',
      uuid: '0000-de00-4000-a000-000000000001'
    },
    departmentAdmin: [{
      id: 8,
      name: 'test-department',
      uuid: '0000-de00-4000-a000-000000000008'
    }],
    email: 'new@example.com',
    enabled: true,
    id: 2,
    isSuperAdmin: false,
    name: 'New Name',
    projectOnly: false,
    projects: [{
      id: 5,
      name: 'project5'
    }, {
      id: 42,
      name: 'computing-the-answer'
    }],
    status: 'enabled',
    username: 'testuser',
    verified: false,
    uuid: '00000000-0500-4000-a000-000000000002'
  });
});
(0, _ava.default)('update()', async t => {
  const clone = { ...MOCK_PROFILE
  };

  function call(method, command, {
    data
  } = {}) {
    if (method === 'GET' && command === 'account') {
      return Promise.resolve({
        objects: [clone]
      });
    }

    if (method === 'PUT' && command === `accounts/${MOCK_PROFILE.id}`) {
      if (data.email) {
        clone.email = data.email;
      }

      if (data.full_name) {
        clone.first_name = data.full_name;
        clone.last_name = '';
      }

      return Promise.resolve('irrelevant');
    }

    throw new Error('unreachable');
  }

  const {
    update
  } = (0, _profile.profile)(call);
  t.deepEqual((await update({
    email: 'new@example.com',
    name: 'New Name'
  })), {
    created: new Date('1920-01-10T12:00:00-0200'),
    department: {
      id: 1,
      name: 'ROOT',
      uuid: '0000-de00-4000-a000-000000000001'
    },
    departmentAdmin: [{
      id: 8,
      name: 'test-department',
      uuid: '0000-de00-4000-a000-000000000008'
    }],
    email: 'new@example.com',
    enabled: true,
    id: 2,
    isSuperAdmin: false,
    name: 'New Name',
    projectOnly: false,
    projects: [{
      id: 5,
      name: 'project5'
    }, {
      id: 42,
      name: 'computing-the-answer'
    }],
    status: 'enabled',
    username: 'testuser',
    verified: false,
    uuid: '00000000-0500-4000-a000-000000000002'
  });
});
(0, _ava.default)('update() defaults full_name to old name', async t => {
  t.plan(1);

  function call(method, command, {
    data
  } = {}) {
    if (method === 'GET' && command === 'account') {
      return Promise.resolve({
        objects: [MOCK_PROFILE]
      });
    }

    if (method === 'PUT' && command === `accounts/${MOCK_PROFILE.id}`) {
      t.is(data.full_name, 'Tester Örn Testason');
      return Promise.resolve('irrelevant');
    }

    throw new Error('unreachable');
  }

  const {
    update
  } = (0, _profile.profile)(call);
  await update({
    email: 'new@example.com'
  });
});