"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _projects = _interopRequireDefault(require("./projects"));

var _objects = require("../../utils/objects");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const MOCK_PROJECTS = [{
  active: true,
  date_created: '2018-06-21T15:36:39Z',
  date_edited: '2018-06-21T15:36:39Z',
  description: 'The description',
  display_name: 'Summer Solstice',
  enabled: true,
  group_name: 'n-hemi-summer-solstice',
  id: 2,
  project_id: 3,
  resource_uri: '/api/v1/user-projects/2/'
}, {
  active: false,
  date_created: '2018-06-20T21:45:23Z',
  date_edited: '2018-06-20T21:45:23Z',
  description: 'Other description',
  display_name: 'AWS',
  enabled: false,
  group_name: 'AWS0123456',
  id: 3,
  project_id: 4,
  resource_uri: '/api/v1/user-projects/3/'
}];
const MOCK_PROJECT_KEYS = {
  api_private_key: 'RG1VNUFvYlVycTlQbUtjVmVXR3hBVzR5Wnc5VEZi',
  api_public_key: 'MXpvUUhSUFliZ28zSkdsak15WWhPZW1jZHZublhh'
};
(0, _ava.default)('list()', async t => {
  t.plan(1);

  const call = _sinon.fake.resolves({
    objects: MOCK_PROJECTS
  });

  const {
    list
  } = (0, _projects.default)(call);
  const data = await list();
  const pruneData = [];
  data.forEach(element => {
    pruneData.push((0, _objects.prune)(element));
  });
  t.deepEqual(pruneData, [{
    id: 2,
    active: true,
    name: 'n-hemi-summer-solstice',
    description: 'The description',
    displayName: 'Summer Solstice',
    projectId: 3,
    created: new Date('2018-06-21T15:36:39.000Z')
  }, {
    id: 3,
    active: false,
    name: 'AWS0123456',
    description: 'Other description',
    displayName: 'AWS',
    projectId: 4,
    created: new Date('2018-06-20T21:45:23.000Z')
  }]);
});
(0, _ava.default)('list(id)', async t => {
  t.plan(2);

  const call = _sinon.fake.resolves(MOCK_PROJECTS[0]);

  const {
    list
  } = (0, _projects.default)(call);
  t.deepEqual((0, _objects.prune)((await list(2))), {
    id: 2,
    active: true,
    name: 'n-hemi-summer-solstice',
    description: 'The description',
    displayName: 'Summer Solstice',
    projectId: 3,
    created: new Date('2018-06-21T15:36:39.000Z')
  });
  t.true(call.calledWith('GET', 'user-projects/2'));
});
(0, _ava.default)('keys', async t => {
  t.plan(2);
  const call = (0, _sinon.fake)((method, command, {
    params
  } = {}) => {
    if (method === 'GET' && command === 'user-projects/2') {
      return Promise.resolve(MOCK_PROJECTS[0]);
    }

    if (method === 'GET' && command === 'account-keys/get_project_keys') {
      t.deepEqual(params, {
        groupName: 'n-hemi-summer-solstice',
        groupId: 2
      });
      return Promise.resolve(MOCK_PROJECT_KEYS);
    }

    throw new Error('unreachable');
  });
  const {
    keys
  } = (0, _projects.default)(call);
  t.deepEqual((await keys(2)), {
    apiKey: 'MXpvUUhSUFliZ28zSkdsak15WWhPZW1jZHZublhh',
    secretKey: 'RG1VNUFvYlVycTlQbUtjVmVXR3hBVzR5Wnc5VEZi'
  });
});