"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = departments;

var _objects = require("../../utils/objects");

function into(department) {
  return {
    created: new Date(department.date_created),
    displayName: department.display_name,
    enabled: department.enabled,
    id: department.id,
    level: department.level,
    name: department.name,
    parent: department.ancestor ? {
      id: department.ancestor.id
    } : null,
    settings: {
      projectOnly: department.disable_personal_accounts
    },
    status: department.enabled ? 'enabled' : 'disabled',
    uuid: department.cs_domain_id || null
  };
}

function intoCreateValues({
  name,
  parent,
  displayName = name,
  enabled = true,
  settings: {
    projectOnly = false
  } = {}
}) {
  return (0, _objects.prune)({
    enabled,
    name,
    cs_domain_name: name,
    disable_personal_accounts: projectOnly,
    display_name: displayName,
    domain: name,
    parent_domain_id: parent ? parent.uuid : undefined
  });
}

function intoUpdateValues({
  displayName,
  enabled,
  settings: {
    projectOnly
  } = {}
}) {
  return (0, _objects.prune)({
    enabled,
    disable_personal_accounts: projectOnly,
    display_name: displayName
  });
}

function departments(call) {
  async function list(id) {
    if (id) {
      const department = await call('GET', `reseller/${id}`);
      return into(department);
    }

    const {
      objects
    } = await call('GET', 'reseller');
    return objects.map(into);
  }

  async function create(values) {
    const data = intoCreateValues(values);
    const {
      id
    } = await call('POST', `reseller`, {
      data
    });
    return list(id);
  }

  async function update(id, values) {
    const data = intoUpdateValues(values);
    await call('PUT', `reseller/${id}`, {
      data
    });
    return list(id);
  }

  async function enable(id) {
    await call('POST', `reseller/${id}/enable`);
    return list(id);
  }

  async function disable(id) {
    await call('POST', `reseller/${id}/disable`);
    return list(id);
  }

  async function remove(id) {
    await call('DELETE', `reseller/${id}`);
    return id;
  }

  return {
    list,
    create,
    update,
    enable,
    disable,
    delete: remove
  };
}