"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _objects = require("../../utils/objects");

var _projects = _interopRequireDefault(require("./projects"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const MOCK_PROJECTS = [Object.freeze({
  account: {
    cs_domain_id: null,
    date_joined: '2018-06-20T20:20:58-0700',
    disable_personal_account: false,
    email: 'noreply@qstack.com',
    first_name: 'Alt+J',
    id: 5,
    is_reseller: false,
    is_superuser: false,
    is_verified: true,
    last_name: '',
    projects: [],
    reseller_id: 1,
    reseller_name: 'ROOT',
    reseller_rights: [],
    resource_uri: '/api/v1/account/5/',
    saml: false,
    state: 0,
    status: 'enabled',
    username: '6WF8OLPE',
    uuid: 'ee44edab-6b91-44b1-aa97-05286754864c'
  },
  source: 'XYZ',
  subscription_number: 'AS123',
  product_code: 'P123',
  accounts: [],
  accounts_count: 0,
  authorized_access: true,
  date_created: '2018-06-20T20:20:58-0700',
  description: '',
  display_name: 'Alt+J',
  enabled: true,
  group_name: '01100011',
  id: 2,
  reseller: {
    cs_domain_id: null,
    cs_domain_name: null,
    date_created: '2018-06-14T19:41:14-0700',
    default_instance_limit: 20,
    default_ip_limit: 20,
    default_network_limit: -1,
    disable_paywall: true,
    disable_personal_accounts: false,
    display_name: 'Department',
    enabled: true,
    id: 1,
    name: 'ROOT',
    resource_uri: '/api/v1/reseller/1/',
    tree_id: 1
  },
  resource_uri: '/api/v1/projects/2/'
}), Object.freeze({
  account: {
    cs_domain_id: null,
    date_joined: '2018-06-20T21:45:02-0700',
    disable_personal_account: false,
    email: 'noreply@qstack.com',
    first_name: 'New project',
    id: 6,
    is_reseller: false,
    is_superuser: false,
    is_verified: true,
    last_name: '',
    projects: [],
    reseller_id: 1,
    reseller_name: 'ROOT',
    reseller_rights: [],
    resource_uri: '/api/v1/account/6/',
    status: 'enabled',
    username: 'YD3AP7IT',
    uuid: 'd71da5fb-6149-4a2d-8b3e-fd217716533a'
  },
  source: 'XYZ',
  subscription_number: 'AS123',
  product_code: 'P123',
  accounts: ['msf'],
  accounts_count: 1,
  date_created: '2018-06-20T21:45:02-0700',
  description: '',
  display_name: 'New Project',
  enabled: true,
  group_name: 'new-proj-0123',
  id: 3,
  reseller: {
    cs_domain_id: null,
    cs_domain_name: null,
    date_created: '2018-06-14T19:41:14-0700',
    default_instance_limit: 20,
    default_ip_limit: 20,
    default_network_limit: -1,
    disable_personal_accounts: false,
    display_name: 'Department',
    enabled: true,
    id: 1,
    name: 'ROOT',
    resource_uri: '/api/v1/reseller/1/'
  },
  resource_uri: '/api/v1/projects/3/'
})];
const MOCK_PROJECT_USERS = [Object.freeze({
  cs_domain_id: null,
  date_joined: '1971-12-20T12:00:00+0200',
  disable_personal_account: false,
  email: 'msf@example.com',
  first_name: 'Médecins',
  id: 5,
  is_superuser: false,
  is_verified: false,
  last_name: 'Sans Frontières',
  projects: [{
    id: 2,
    name: '01100011'
  }],
  reseller_id: 1,
  reseller_name: 'ROOT',
  reseller_rights: [],
  status: 'enabled',
  username: 'msf',
  uuid: '00000000-0500-4000-a000-000000000005'
})];
const TRANSFORMED_PROJECTS = [{
  account: {
    id: 5,
    username: '6WF8OLPE',
    uuid: 'ee44edab-6b91-44b1-aa97-05286754864c'
  },
  accounts: [],
  created: new Date('2018-06-21T03:20:58.000Z'),
  department: {
    id: 1,
    uuid: null
  },
  description: '',
  displayName: 'Alt+J',
  enabled: true,
  id: 2,
  name: '01100011',
  type: 'XYZ',
  subscriptionNumber: 'AS123',
  productCode: 'P123'
}, {
  account: {
    id: 6,
    username: 'YD3AP7IT',
    uuid: 'd71da5fb-6149-4a2d-8b3e-fd217716533a'
  },
  type: 'XYZ',
  subscriptionNumber: 'AS123',
  productCode: 'P123',
  accounts: ['msf'],
  created: new Date('2018-06-21T04:45:02.000Z'),
  department: {
    id: 1,
    uuid: null
  },
  description: '',
  displayName: 'New Project',
  enabled: true,
  id: 3,
  name: 'new-proj-0123'
}];
const TRANSFORMED_PROJECT_USERS = [Object.freeze({
  created: new Date('1971-12-20T10:00:00Z'),
  department: {
    id: 1,
    name: 'ROOT',
    uuid: null
  },
  departmentAdmin: [],
  email: 'msf@example.com',
  enabled: true,
  id: 5,
  isSuperAdmin: false,
  name: 'Médecins Sans Frontières',
  projectOnly: false,
  projects: [{
    id: 2,
    name: '01100011'
  }],
  status: 'enabled',
  username: 'msf',
  uuid: '00000000-0500-4000-a000-000000000005',
  verified: false
})];

function fakeRoutes(routes = []) {
  return async (method, command, {
    data,
    params
  } = {}) => {
    // eslint-disable-next-line no-restricted-syntax
    for (const route of routes) {
      if (method === route.method && command === route.command) {
        return route.fn({
          data,
          params
        });
      }
    }

    if (method === 'GET' && command === 'projects') {
      return MOCK_PROJECTS;
    }

    if (method === 'GET' && command === 'projects/2') {
      return MOCK_PROJECTS[0];
    }

    if (method === 'GET' && command === 'projects/3') {
      return MOCK_PROJECTS[1];
    }

    throw new Error('unreachable');
  };
}

(0, _ava.default)('list()', async t => {
  const call = _sinon.fake.resolves({
    objects: MOCK_PROJECTS
  });

  const {
    list
  } = (0, _projects.default)(call);
  const data = await list();
  const pruneData = [];
  data.forEach(element => {
    pruneData.push((0, _objects.prune)(element));
  });
  t.deepEqual(pruneData, TRANSFORMED_PROJECTS);
});
(0, _ava.default)('list(id)', async t => {
  const call = _sinon.fake.resolves(MOCK_PROJECTS[1]);

  const {
    list
  } = (0, _projects.default)(call);
  t.deepEqual((0, _objects.prune)((await list(3))), TRANSFORMED_PROJECTS[1]);
});
(0, _ava.default)('keys(id)', async t => {
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'GET',
    command: 'account-keys/get_user_keys',

    fn({
      params
    }) {
      if (params.username === '6WF8OLPE') {
        return {
          api_private_key: 'secret-key',
          api_public_key: 'api-key'
        };
      }

      return {};
    }

  }]));
  const {
    keys
  } = (0, _projects.default)(call);
  t.deepEqual((await keys(2)), {
    apiKey: 'api-key',
    secretKey: 'secret-key'
  });
});
(0, _ava.default)('create()', async t => {
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'POST',
    command: 'projects',
    fn: () => ({
      id: 2
    })
  }]));
  const {
    create
  } = (0, _projects.default)(call);
  const createData = { ...TRANSFORMED_PROJECTS[0],
    type: 'XYZ',
    subscriptionNumber: 'AS123',
    productCode: 'P123'
  };
  t.deepEqual((await create({
    name: '01100011',
    displayName: 'Display name',
    description: 'Alt+J',
    department: 1,
    type: 'XYZ',
    subscriptionNumber: 'AS123',
    productCode: 'P123'
  })), createData);
  t.true(call.calledWith('POST', 'projects', {
    data: {
      group_name: '01100011',
      display_name: 'Display name',
      description: 'Alt+J',
      reseller_id: 1,
      source: 'XYZ',
      subscription_number: 'AS123',
      product_code: 'P123'
    }
  }));
});
(0, _ava.default)('create() - default display_name/description', async t => {
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'POST',
    command: 'projects',
    fn: () => ({
      id: 3
    })
  }]));
  const {
    create
  } = (0, _projects.default)(call);
  const createData = { ...TRANSFORMED_PROJECTS[1],
    type: 'XYZ',
    subscriptionNumber: 'AS123',
    productCode: 'P123'
  };
  t.deepEqual((await create({
    name: 'new-proj-0123',
    department: 1,
    type: 'XYZ',
    subscriptionNumber: 'AS123',
    productCode: 'P123'
  })), createData);
  t.true(call.calledWith('POST', 'projects', {
    data: {
      group_name: 'new-proj-0123',
      description: '',
      display_name: 'new-proj-0123',
      reseller_id: 1,
      source: 'XYZ',
      subscription_number: 'AS123',
      product_code: 'P123'
    }
  }));
});
(0, _ava.default)('update()', async t => {
  const clone = { ...MOCK_PROJECTS[0]
  };
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'PUT',
    command: 'projects/2',

    fn({
      data
    }) {
      Object.assign(clone, data);
      return 'irrelevant';
    }

  }, {
    method: 'GET',
    command: 'projects/2',
    fn: () => clone
  }]));
  const {
    update
  } = (0, _projects.default)(call);
  t.deepEqual((0, _objects.prune)((await update(2, {
    displayName: 'New display name',
    description: 'New description'
  }))), { ...TRANSFORMED_PROJECTS[0],
    displayName: 'New display name',
    description: 'New description'
  });
});
(0, _ava.default)('enable()', async t => {
  const call = _sinon.fake.resolves(MOCK_PROJECTS[1]);

  const {
    enable
  } = (0, _projects.default)(call);
  t.deepEqual((0, _objects.prune)((await enable(3))), TRANSFORMED_PROJECTS[1]);
  t.true(call.calledWith('POST', 'projects/3/enable'));
});
(0, _ava.default)('disable()', async t => {
  const call = _sinon.fake.resolves(MOCK_PROJECTS[1]);

  const {
    disable
  } = (0, _projects.default)(call);
  t.deepEqual((0, _objects.prune)((await disable(3))), TRANSFORMED_PROJECTS[1]);
  t.true(call.calledWith('POST', 'projects/3/disable'));
});
(0, _ava.default)('listUsers()', async t => {
  const call = _sinon.fake.resolves(MOCK_PROJECT_USERS);

  const {
    listUsers
  } = (0, _projects.default)(call);
  t.deepEqual((await listUsers(2)), TRANSFORMED_PROJECT_USERS);
  t.true(call.calledWith('GET', 'projects/2/users'));
});
(0, _ava.default)('addUser()', async t => {
  const call = _sinon.fake.resolves(MOCK_PROJECTS[0]);

  const {
    addUser
  } = (0, _projects.default)(call);
  t.deepEqual((0, _objects.prune)((await addUser(2, 'foo'))), TRANSFORMED_PROJECTS[0]);
  t.true(call.calledWith('POST', 'projects/2/add_user', {
    data: {
      username: 'foo'
    }
  }));
});
(0, _ava.default)('removeUser()', async t => {
  const call = _sinon.fake.resolves(MOCK_PROJECTS[1]);

  const {
    removeUser
  } = (0, _projects.default)(call);
  t.deepEqual((0, _objects.prune)((await removeUser(3, 'msf'))), TRANSFORMED_PROJECTS[1]);
  t.true(call.calledWith('POST', 'projects/3/remove_user', {
    data: {
      username: 'msf'
    }
  }));
});
(0, _ava.default)('delete()', async t => {
  const call = _sinon.fake.resolves('irrelevant');

  const {
    delete: remove
  } = (0, _projects.default)(call);
  t.is((await remove(2)), 2);
  t.true(call.calledWith('GET', 'projects/2/delete'));
});