"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.gqConsoleUsers = gqConsoleUsers;
exports.users = users;
Object.defineProperty(exports, "into", {
  enumerable: true,
  get: function () {
    return _profile.into;
  }
});

var _objects = require("../../utils/objects");

var _profile = require("../account/profile");

function intoCreateValues({
  email,
  department,
  name,
  password,
  username
}) {
  return (0, _objects.prune)({
    email,
    password,
    username,
    fullName: name,
    resellerId: department
  });
}

function intoUpdateValues({
  email,
  name
}) {
  return (0, _objects.prune)({
    email,
    full_name: name
  });
}

function gqConsoleUsers(call) {
  async function list() {
    const objects = await call('GET', 'account/simple_user_list');
    return objects.map(_profile.into);
  }

  async function get(username) {
    const user = await call('GET', 'account/user', {
      params: {
        username
      }
    });
    return (0, _profile.into)(user);
  }

  async function keys(params) {
    const result = await call('GET', 'account-keys/get_user_keys', {
      params
    });
    return {
      apiKey: result.api_public_key,
      secretKey: result.api_private_key
    };
  }

  async function create(values) {
    const data = intoCreateValues(values);
    const user = await call('POST', 'account', {
      data
    });
    return (0, _profile.into)(user);
  }

  async function update(username, values) {
    const {
      id
    } = await get(username);
    const data = intoUpdateValues(values);
    await call('PUT', `account/${id}`, {
      data
    });
    return get(username);
  }

  async function changePassword(username, newPassword) {
    return call('PUT', `account/change_password_admin`, {
      data: {
        username,
        password1: newPassword
      }
    });
  }

  async function enable(username) {
    return call('GET', 'account/enable_user', {
      params: {
        username
      }
    });
  }

  async function disable(username) {
    return call('GET', 'account/disable_user', {
      params: {
        username
      }
    });
  }

  async function addSuperAdmin(username) {
    const {
      id
    } = await get(username);
    return call('POST', `accounts/${id}/superuser/enable`, {
      version: ''
    });
  }

  async function removeSuperAdmin(username) {
    const {
      id
    } = await get(username);
    return call('POST', `accounts/${id}/superuser/disable`, {
      version: ''
    });
  }

  async function remove(username) {
    const {
      id
    } = await get(username);
    await call('DELETE', `account/${id}`);
    return id;
  }

  return {
    list,
    get,
    keys,
    create,
    update,
    changePassword,
    enable,
    disable,
    addSuperAdmin,
    removeSuperAdmin,
    delete: remove
  };
}

function users(call) {
  async function list() {
    const objects = await call('GET', 'simple_user_list');
    return objects.map(_profile.into);
  }

  async function get(username) {
    const user = await call('GET', 'account/user', {
      params: {
        username
      }
    });
    return (0, _profile.into)(user);
  }

  async function keys(params) {
    const result = await call('GET', 'account-keys/get_user_keys', {
      params
    });
    return {
      apiKey: result.api_public_key,
      secretKey: result.api_private_key
    };
  }

  async function create(values) {
    const data = intoCreateValues(values);
    const user = await call('POST', 'accounts', {
      data
    });
    return (0, _profile.into)(user);
  }

  async function update(username, values) {
    const {
      id
    } = await get(username);
    const data = intoUpdateValues(values);
    await call('PUT', `accounts/${id}`, {
      data
    });
    return get(username);
  }

  async function changePassword(username, newPassword) {
    const {
      id
    } = await get(username);
    return call('PUT', `accounts/${id}/password_admin`, {
      data: {
        password1: newPassword
      }
    });
  }

  async function enable(username) {
    const {
      id
    } = await get(username);
    return call('PUT', `accounts/${id}/status/enabled`);
  }

  async function disable(username) {
    const {
      id
    } = await get(username);
    return call('DELETE', `accounts/${id}/status/enabled`);
  }

  async function addSuperAdmin(username) {
    const {
      id
    } = await get(username);
    return call('PUT', `accounts/${id}/superuser`);
  }

  async function removeSuperAdmin(username) {
    const {
      id
    } = await get(username);
    return call('DELETE', `accounts/${id}/superuser`);
  }

  async function remove(username) {
    const {
      id
    } = await get(username);
    await call('DELETE', `accounts/${id}`);
    return id;
  }

  return {
    list,
    get,
    keys,
    create,
    update,
    changePassword,
    enable,
    disable,
    addSuperAdmin,
    removeSuperAdmin,
    delete: remove
  };
}