"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _users = require("./users");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const MOCK_ADMIN = Object.freeze({
  cs_domain_id: '0000-de00-4000-a000-000000000001',
  date_joined: '1920-01-10T12:00:00+0200',
  disable_personal_account: false,
  email: 'no-reply@qstack.com',
  first_name: '',
  id: 1,
  is_superuser: true,
  is_verified: false,
  last_name: '',
  projects: [],
  reseller_id: 1,
  reseller_name: 'ROOT',
  reseller_rights: [{
    id: 1,
    domain_id: '0000-de00-4000-a000-000000000001',
    name: 'ROOT'
  }, {
    id: 8,
    domain_id: '0000-de00-4000-a000-000000000008',
    name: 'test-department'
  }],
  status: 'enabled',
  username: 'admin',
  uuid: '00000000-0500-4000-a000-000000000001'
});
const MOCK_TESTUSER = Object.freeze({
  cs_domain_id: '0000-de00-4000-a000-000000000001',
  date_joined: '1945-10-24T12:00:00-0800',
  disable_personal_account: false,
  email: 'testuser@example.com',
  first_name: 'Tester Örn',
  id: 2,
  is_superuser: false,
  is_verified: false,
  last_name: 'Testason',
  projects: [{
    id: 5,
    name: 'project5'
  }, {
    id: 42,
    name: 'computing-the-answer'
  }],
  reseller_id: 1,
  reseller_name: 'ROOT',
  reseller_rights: [{
    id: 8,
    domain_id: '0000-de00-4000-a000-000000000008',
    name: 'test-department'
  }],
  status: 'enabled',
  username: 'testuser',
  uuid: '00000000-0500-4000-a000-000000000002'
});
const MOCK_USERS = Object.freeze([MOCK_ADMIN, MOCK_TESTUSER]);
const MOCK_NEWUSER = Object.freeze({
  cs_domain_id: '0000-de00-4000-a000-000000000001',
  date_joined: '1971-12-20T12:00:00+0200',
  disable_personal_account: false,
  email: 'msf@example.com',
  first_name: 'Médecins',
  id: 5,
  is_superuser: false,
  is_verified: false,
  last_name: 'Sans Frontières',
  projects: [],
  reseller_id: 1,
  reseller_name: 'ROOT',
  reseller_rights: [],
  status: 'enabled',
  username: 'msf',
  uuid: '00000000-0500-4000-a000-000000000005'
});
const TRANSFORMED_ADMIN = Object.freeze({
  created: new Date('1920-01-10T10:00:00Z'),
  department: {
    id: 1,
    name: 'ROOT',
    uuid: '0000-de00-4000-a000-000000000001'
  },
  departmentAdmin: [{
    id: 1,
    name: 'ROOT',
    uuid: '0000-de00-4000-a000-000000000001'
  }, {
    id: 8,
    name: 'test-department',
    uuid: '0000-de00-4000-a000-000000000008'
  }],
  email: 'no-reply@qstack.com',
  enabled: true,
  id: 1,
  isSuperAdmin: true,
  name: 'admin',
  projectOnly: false,
  projects: [],
  status: 'enabled',
  username: 'admin',
  verified: false,
  uuid: '00000000-0500-4000-a000-000000000001'
});
const TRANSFORMED_TESTUSER = Object.freeze({
  created: new Date('1945-10-24T12:00:00-0800'),
  department: {
    id: 1,
    name: 'ROOT',
    uuid: '0000-de00-4000-a000-000000000001'
  },
  departmentAdmin: [{
    id: 8,
    name: 'test-department',
    uuid: '0000-de00-4000-a000-000000000008'
  }],
  email: 'testuser@example.com',
  enabled: true,
  id: 2,
  isSuperAdmin: false,
  name: 'Tester Örn Testason',
  projectOnly: false,
  projects: [{
    id: 5,
    name: 'project5'
  }, {
    id: 42,
    name: 'computing-the-answer'
  }],
  status: 'enabled',
  username: 'testuser',
  verified: false,
  uuid: '00000000-0500-4000-a000-000000000002'
});
const TRANSFORMED_NEWUSER = Object.freeze({
  created: new Date('1971-12-20T10:00:00Z'),
  department: {
    id: 1,
    name: 'ROOT',
    uuid: '0000-de00-4000-a000-000000000001'
  },
  departmentAdmin: [],
  email: 'msf@example.com',
  enabled: true,
  id: 5,
  isSuperAdmin: false,
  name: 'Médecins Sans Frontières',
  projectOnly: false,
  projects: [],
  status: 'enabled',
  username: 'msf',
  uuid: '00000000-0500-4000-a000-000000000005',
  verified: false
});

function fakeRoutes(routes = []) {
  return async (method, command, {
    data,
    params
  } = {}) => {
    // eslint-disable-next-line no-restricted-syntax
    for (const route of routes) {
      if (method === route.method && command === route.command) {
        return route.fn({
          data,
          params
        });
      }
    }

    if (method === 'GET' && (command === 'simple_user_list' || command === 'account/simple_user_list')) {
      return MOCK_USERS;
    }

    if (method === 'GET' && command === 'account/user') {
      return MOCK_TESTUSER;
    }

    throw new Error('unreachable');
  };
}

let clock;

_ava.default.before(() => {
  clock = (0, _sinon.useFakeTimers)(new Date('2012-12-21T21:12:02Z').getTime());
});

_ava.default.after(() => {
  clock.restore();
});

(0, _ava.default)('list()', async t => {
  const call = _sinon.fake.resolves(MOCK_USERS);

  const {
    list
  } = (0, _users.users)(call);
  t.deepEqual((await list()), [TRANSFORMED_ADMIN, TRANSFORMED_TESTUSER]);
});
(0, _ava.default)('get(username)', async t => {
  const call = _sinon.fake.resolves(MOCK_TESTUSER);

  const {
    get
  } = (0, _users.users)(call);
  t.deepEqual((await get(MOCK_TESTUSER.username)), TRANSFORMED_TESTUSER);
});
(0, _ava.default)('keys(id)', async t => {
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'GET',
    command: 'account-keys/get_user_keys',

    fn({
      params
    }) {
      if (params.username === 'testuser') {
        return {
          api_private_key: 'secret-key',
          api_public_key: 'api-key'
        };
      }

      if (params.uuid === 'randomid') {
        return {
          api_private_key: 'uuid-secret-key',
          api_public_key: 'uuid-api-key'
        };
      }

      return {};
    }

  }]));
  const {
    keys
  } = (0, _users.users)(call);
  t.deepEqual((await keys({
    username: MOCK_TESTUSER.username
  })), {
    apiKey: 'api-key',
    secretKey: 'secret-key'
  });
  t.deepEqual((await keys({
    uuid: 'randomid'
  })), {
    apiKey: 'uuid-api-key',
    secretKey: 'uuid-secret-key'
  });
});
(0, _ava.default)('gq-console-create()', async t => {
  const call = _sinon.fake.resolves(MOCK_NEWUSER);

  const {
    create
  } = (0, _users.gqConsoleUsers)(call);
  t.deepEqual((await create({
    email: 'msf@example.com',
    name: 'Médecins Sans Frontières',
    password: 'irrelevant',
    username: 'msf'
  })), TRANSFORMED_NEWUSER);
  t.true(call.calledWith('POST', 'account', {
    data: {
      email: 'msf@example.com',
      fullName: 'Médecins Sans Frontières',
      password: 'irrelevant',
      username: 'msf'
    }
  }));
});
(0, _ava.default)('create()', async t => {
  const call = _sinon.fake.resolves(MOCK_NEWUSER);

  const {
    create
  } = (0, _users.users)(call);
  t.deepEqual((await create({
    email: 'msf@example.com',
    name: 'Médecins Sans Frontières',
    password: 'irrelevant',
    username: 'msf'
  })), TRANSFORMED_NEWUSER);
  t.true(call.calledWith('POST', 'accounts', {
    data: {
      email: 'msf@example.com',
      fullName: 'Médecins Sans Frontières',
      password: 'irrelevant',
      username: 'msf'
    }
  }));
});
(0, _ava.default)('gq-console-update()', async t => {
  const clone = { ...MOCK_NEWUSER
  };
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'GET',
    command: `account/user`,

    fn() {
      return clone;
    }

  }, {
    method: 'PUT',
    command: `account/${MOCK_NEWUSER.id}`,

    fn({
      data
    }) {
      if (typeof data.email !== 'undefined') {
        clone.email = data.email;
      }

      if (typeof data.full_name !== 'undefined') {
        clone.first_name = data.full_name;
        clone.last_name = '';
      }

      return 'irrelevant';
    }

  }]));
  const {
    update
  } = (0, _users.gqConsoleUsers)(call);
  t.deepEqual((await update(MOCK_NEWUSER.id, {
    name: 'New Name'
  })), { ...TRANSFORMED_NEWUSER,
    name: 'New Name'
  });
  t.deepEqual((await update(MOCK_NEWUSER.id, {
    email: 'new@example.com'
  })), { ...TRANSFORMED_NEWUSER,
    email: 'new@example.com',
    name: 'New Name'
  }, 'name unchanged');
  t.deepEqual((await update(MOCK_NEWUSER.id, {
    name: ''
  })), { ...TRANSFORMED_NEWUSER,
    email: 'new@example.com',
    name: 'msf'
  }, 'name empty');
});
(0, _ava.default)('update()', async t => {
  const clone = { ...MOCK_NEWUSER
  };
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'GET',
    command: `account/user`,

    fn() {
      return clone;
    }

  }, {
    method: 'PUT',
    command: `accounts/${MOCK_NEWUSER.id}`,

    fn({
      data
    }) {
      if (typeof data.email !== 'undefined') {
        clone.email = data.email;
      }

      if (typeof data.full_name !== 'undefined') {
        clone.first_name = data.full_name;
        clone.last_name = '';
      }

      return 'irrelevant';
    }

  }]));
  const {
    update
  } = (0, _users.users)(call);
  t.deepEqual((await update(MOCK_NEWUSER.id, {
    name: 'New Name'
  })), { ...TRANSFORMED_NEWUSER,
    name: 'New Name'
  });
  t.deepEqual((await update(MOCK_NEWUSER.id, {
    email: 'new@example.com'
  })), { ...TRANSFORMED_NEWUSER,
    email: 'new@example.com',
    name: 'New Name'
  }, 'name unchanged');
  t.deepEqual((await update(MOCK_NEWUSER.id, {
    name: ''
  })), { ...TRANSFORMED_NEWUSER,
    email: 'new@example.com',
    name: 'msf'
  }, 'name empty');
});
(0, _ava.default)('gq-console-changePassword()', async t => {
  const call = _sinon.fake.resolves(MOCK_USERS);

  const {
    changePassword
  } = (0, _users.gqConsoleUsers)(call);
  t.deepEqual((await changePassword(MOCK_TESTUSER.username, 'newpassword')), MOCK_USERS);
  t.false(call.calledWith('POST', 'account/change_password_admin', {
    data: {
      username: 'testuser',
      password1: 'newpassword'
    }
  }));
});
(0, _ava.default)('changePassword()', async t => {
  const clone = { ...MOCK_TESTUSER
  };
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'GET',
    command: `account/user`,

    fn() {
      return clone;
    }

  }, {
    method: 'PUT',
    command: `accounts/${MOCK_TESTUSER.id}/password_admin`,

    fn() {
      return 'irrelevant';
    }

  }]));
  const {
    changePassword
  } = (0, _users.users)(call);
  t.is((await changePassword(MOCK_TESTUSER.username, 'newpassword')), 'irrelevant');
  t.true(call.calledWith('PUT', `accounts/${MOCK_TESTUSER.id}/password_admin`, {
    data: {
      password1: 'newpassword'
    }
  }));
});
(0, _ava.default)('gq-console-enable()', async t => {
  const call = _sinon.fake.resolves(MOCK_USERS);

  const {
    enable
  } = (0, _users.gqConsoleUsers)(call);
  t.deepEqual((await enable(MOCK_TESTUSER.username)), MOCK_USERS);
  t.true(call.calledWith('GET', 'account/enable_user', {
    params: {
      username: 'testuser'
    }
  }));
});
(0, _ava.default)('enable()', async t => {
  const clone = { ...MOCK_TESTUSER
  };
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'GET',
    command: `account/user`,

    fn() {
      return clone;
    }

  }, {
    method: 'PUT',
    command: `accounts/${MOCK_TESTUSER.id}/status/enabled`,

    fn() {
      return 'irrelevant';
    }

  }]));
  const {
    enable
  } = (0, _users.users)(call);
  t.is((await enable(MOCK_TESTUSER.username)), 'irrelevant');
  t.true(call.calledWith('PUT', `accounts/${MOCK_TESTUSER.id}/status/enabled`));
});
(0, _ava.default)('gq-console-disable()', async t => {
  const call = _sinon.fake.resolves(MOCK_USERS);

  const {
    disable
  } = (0, _users.gqConsoleUsers)(call);
  t.deepEqual((await disable(MOCK_TESTUSER.username)), MOCK_USERS);
  t.true(call.calledWith('GET', 'account/disable_user', {
    params: {
      username: 'testuser'
    }
  }));
});
(0, _ava.default)('disable()', async t => {
  const clone = { ...MOCK_TESTUSER
  };
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'GET',
    command: `account/user`,

    fn() {
      return clone;
    }

  }, {
    method: 'DELETE',
    command: `accounts/${MOCK_TESTUSER.id}/status/enabled`,

    fn() {
      return 'irrelevant';
    }

  }]));
  const {
    disable
  } = (0, _users.users)(call);
  t.is((await disable(MOCK_TESTUSER.username)), 'irrelevant');
  t.true(call.calledWith('DELETE', `accounts/${MOCK_TESTUSER.id}/status/enabled`));
});
(0, _ava.default)('gq-console-addSuperAdmin()', async t => {
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'POST',
    command: `accounts/${MOCK_TESTUSER.id}/superuser/enable`,

    fn() {
      return 'irrelevant';
    }

  }]));
  const {
    addSuperAdmin
  } = (0, _users.gqConsoleUsers)(call);
  t.is((await addSuperAdmin(MOCK_TESTUSER.username)), 'irrelevant');
  t.true(call.calledWith('POST', 'accounts/2/superuser/enable', {
    version: ''
  }));
});
(0, _ava.default)('addSuperAdmin()', async t => {
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'PUT',
    command: `accounts/${MOCK_TESTUSER.id}/superuser`,

    fn() {
      return 'irrelevant';
    }

  }]));
  const {
    addSuperAdmin
  } = (0, _users.users)(call);
  t.is((await addSuperAdmin(MOCK_TESTUSER.username)), 'irrelevant');
  t.true(call.calledWith('PUT', 'accounts/2/superuser'));
});
(0, _ava.default)('gq-console-removeSuperAdmin()', async t => {
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'POST',
    command: `accounts/${MOCK_TESTUSER.id}/superuser/disable`,

    fn() {
      return 'irrelevant';
    }

  }]));
  const {
    removeSuperAdmin
  } = (0, _users.gqConsoleUsers)(call);
  t.is((await removeSuperAdmin(MOCK_TESTUSER.username)), 'irrelevant');
  t.true(call.calledWith('POST', 'accounts/2/superuser/disable', {
    version: ''
  }));
});
(0, _ava.default)('removeSuperAdmin()', async t => {
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'DELETE',
    command: `accounts/${MOCK_TESTUSER.id}/superuser`,

    fn() {
      return 'irrelevant';
    }

  }]));
  const {
    removeSuperAdmin
  } = (0, _users.users)(call);
  t.is((await removeSuperAdmin(MOCK_TESTUSER.username)), 'irrelevant');
  t.true(call.calledWith('DELETE', 'accounts/2/superuser'));
});
(0, _ava.default)('gq-console-delete()', async t => {
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'DELETE',
    command: `account/${MOCK_TESTUSER.id}`,

    fn() {
      return 'irrelevant';
    }

  }]));
  const {
    delete: remove
  } = (0, _users.gqConsoleUsers)(call);
  t.is((await remove(MOCK_TESTUSER.username)), 2);
  t.true(call.calledWith('DELETE', 'account/2'));
});
(0, _ava.default)('delete()', async t => {
  const call = (0, _sinon.fake)(fakeRoutes([{
    method: 'DELETE',
    command: `accounts/${MOCK_TESTUSER.id}`,

    fn() {
      return 'irrelevant';
    }

  }]));
  const {
    delete: remove
  } = (0, _users.users)(call);
  t.is((await remove(MOCK_TESTUSER.username)), 2);
  t.true(call.calledWith('DELETE', 'accounts/2'));
});