"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = cloudSync;

var _cloudSync = _interopRequireDefault(require("../../service/cloud-sync"));

var _logger = _interopRequireDefault(require("../../logger"));

var _dataBrokers = _interopRequireDefault(require("./data-brokers"));

var _messages = _interopRequireDefault(require("./messages"));

var _nfs = _interopRequireDefault(require("./nfs"));

var _relationships = _interopRequireDefault(require("./relationships"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Manage cloud sync resources.
 *
 * @example
 *
 * import api from 'qstack-client/api/cloud-sync';
 *
 * const conf = {
 *   onbehalfToken: 'JWT token',
 *   tolen: 'JWT token',
 *   url: 'http://cloud-sync.example.com',
 * };
 *
 * api(conf).relationships.list();
 */
function cloudSync(conf) {
  _logger.default.silly(`CloudSync conf=${JSON.stringify(conf)}`);

  function call(method, command, data, params) {
    return (0, _cloudSync.default)(conf, method, command, data, params);
  }

  return {
    dataBrokers: (0, _dataBrokers.default)(call),
    messages: (0, _messages.default)(call),
    nfs: (0, _nfs.default)(call),
    relationships: (0, _relationships.default)(call)
  };
}