"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _relationships = _interopRequireDefault(require("./relationships"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UUID_1 = '9760acf5-4638-11e7-9bdb-020073ca7773';
const relationshipsStub = (0, _sinon.stub)();
const {
  abort,
  create,
  list,
  update,
  sync,
  delete: remove
} = (0, _relationships.default)(relationshipsStub);
relationshipsStub.withArgs('GET', 'relationships-v2').resolves([{
  name: 'all entries'
}]);
relationshipsStub.withArgs('GET', `relationships-v2/${UUID_1}`).resolves({
  name: 'single entry'
});
const createStub = relationshipsStub.withArgs('POST', 'relationships-v2').resolves({
  name: 'new entry'
});
const updateStub = relationshipsStub.withArgs('PUT', `relationships/${UUID_1}/sync-schedule`).resolves({
  name: 'updated entry'
});
relationshipsStub.withArgs('PUT', `relationships/${UUID_1}/sync`).resolves({
  name: 'synced entry'
});
relationshipsStub.withArgs('PUT', `relationships/${UUID_1}/abort`).resolves({
  name: 'aborted entry'
});
relationshipsStub.withArgs('DELETE', `relationships/${UUID_1}`).resolves({
  status: 'deleted'
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    name: 'all entries'
  }]);
});
(0, _ava.default)('list(id)', async t => {
  t.deepEqual((await list(UUID_1)), {
    name: 'single entry'
  });
});
(0, _ava.default)('create(values)', async t => {
  t.deepEqual((await create({
    name: 'foo'
  })), {
    name: 'new entry'
  });
  t.deepEqual(createStub.firstCall.args[2], {
    name: 'foo'
  });
});
(0, _ava.default)('update(id, values)', async t => {
  t.deepEqual((await update(UUID_1, {
    name: 'bar'
  })), {
    name: 'updated entry'
  });
  t.deepEqual(updateStub.firstCall.args[2], {
    name: 'bar'
  });
});
(0, _ava.default)('sync(id)', async t => {
  t.deepEqual((await sync(UUID_1)), {
    name: 'synced entry'
  });
});
(0, _ava.default)('abort(id)', async t => {
  t.deepEqual((await abort(UUID_1)), {
    name: 'aborted entry'
  });
});
(0, _ava.default)('remove(id)', async t => {
  t.deepEqual((await remove(UUID_1)), {
    status: 'deleted'
  });
});