"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _activeDirectory = _interopRequireDefault(require("./active-directory"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UUID_1 = '9760acf5-4638-11e7-9bdb-020073ca7773';
const UUID_2 = '5fca0679-4638-11e7-9bdb-020073ca7773';
const DATE_1 = '2018-02-21T00:00:04.000Z';
const DATE_2 = '2018-02-21T00:15:01.000Z';
const MOCK_ACTIVE_DIRECTORIES = [{
  UUID: UUID_1,
  username: 'username1',
  password: '****************',
  domain: 'domain1',
  DNS: 'dns1',
  netBIOS: 'netbios1',
  organizationalUnit: 'CN=Computers',
  region: 'region1',
  status: 'created',
  createdAt: DATE_1,
  updatedAt: DATE_2
}, {
  UUID: UUID_2,
  username: 'username2',
  password: '****************',
  domain: 'domain2',
  DNS: 'dns2',
  netBIOS: 'netbios2',
  organizationalUnit: 'CN=Computers',
  region: 'region2',
  status: 'in use',
  createdAt: DATE_1,
  updatedAt: DATE_2
}];
const activeDirectoryStub = (0, _sinon.stub)();
const {
  create,
  list,
  update,
  delete: remove
} = (0, _activeDirectory.default)(activeDirectoryStub);
activeDirectoryStub.withArgs('GET', 'Storage/ActiveDirectory').resolves(MOCK_ACTIVE_DIRECTORIES);
const createStub = activeDirectoryStub.withArgs('POST', 'Storage/ActiveDirectory').resolves({ ...MOCK_ACTIVE_DIRECTORIES[0],
  username: 'New entry'
});
const updateStub = activeDirectoryStub.withArgs('PUT', `Storage/ActiveDirectory/${UUID_1}`).resolves({ ...MOCK_ACTIVE_DIRECTORIES[0],
  username: 'Updated entry'
});
activeDirectoryStub.withArgs('DELETE', `Storage/ActiveDirectory/${UUID_1}`).resolves({
  status: 'deleted'
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: UUID_1,
    username: 'username1',
    password: '****************',
    domain: 'domain1',
    dns: 'dns1',
    netbios: 'netbios1',
    organizationalUnit: 'CN=Computers',
    region: 'region1',
    status: 'created',
    created: new Date(DATE_1),
    updated: new Date(DATE_2)
  }, {
    id: UUID_2,
    username: 'username2',
    password: '****************',
    domain: 'domain2',
    dns: 'dns2',
    netbios: 'netbios2',
    organizationalUnit: 'CN=Computers',
    region: 'region2',
    status: 'in use',
    created: new Date(DATE_1),
    updated: new Date(DATE_2)
  }]);
});
(0, _ava.default)('create(values)', async t => {
  t.deepEqual((await create({
    name: 'foo'
  })), {
    id: UUID_1,
    username: 'New entry',
    password: '****************',
    domain: 'domain1',
    dns: 'dns1',
    netbios: 'netbios1',
    organizationalUnit: 'CN=Computers',
    region: 'region1',
    status: 'created',
    created: new Date(DATE_1),
    updated: new Date(DATE_2)
  });
  t.deepEqual(createStub.firstCall.args[2], {
    name: 'foo'
  });
});
(0, _ava.default)('update(id, values)', async t => {
  t.deepEqual((await update(UUID_1, {
    name: 'bar'
  })), {
    id: UUID_1,
    username: 'Updated entry',
    password: '****************',
    domain: 'domain1',
    dns: 'dns1',
    netbios: 'netbios1',
    organizationalUnit: 'CN=Computers',
    region: 'region1',
    status: 'created',
    created: new Date(DATE_1),
    updated: new Date(DATE_2)
  });
  t.deepEqual(updateStub.firstCall.args[2], {
    name: 'bar'
  });
});
(0, _ava.default)('remove(id)', async t => {
  t.deepEqual((await remove(UUID_1)), {
    status: 'deleted'
  });
});