"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = backups;

var _jobs = require("./utils/jobs");

function into(backup) {
  return {
    id: backup.backupId,
    name: backup.name,
    tag: backup.tag || null,
    type: backup.type || null,
    ownerId: backup.ownerId,
    region: backup.region,
    usedBytes: backup.usedBytes,
    volumeId: backup.volumeId,
    lifeCycle: {
      state: backup.lifeCycleState,
      details: backup.lifeCycleStateDetails
    },
    created: new Date(backup.created)
  };
}

function backups(call) {
  function intoAsync(backup) {
    return {
      value: into(backup),

      finish(sideEffect, interval, timeout, interrupt) {
        return Promise.all(backup.jobs.map(job => (0, _jobs.finish)(call, job.jobId, sideEffect, interval, timeout, interrupt)));
      }

    };
  }

  return {
    async list(volumeId, id) {
      if (volumeId && id) {
        return into((await call('GET', `Volumes/${volumeId}/Backups/${id}`)));
      }

      if (volumeId) {
        return (await call('GET', `Volumes/${volumeId}/Backups`)).map(into);
      }

      if (id) {
        return into((await call('GET', `Backups/${id}`)));
      }

      return (await call('GET', 'Backups')).map(into);
    },

    async create(volumeId, values) {
      if (volumeId) {
        return intoAsync((await call('POST', `Volumes/${volumeId}/Backups`, values)));
      }

      return intoAsync((await call('POST', 'Backups', values)));
    },

    async update(id, values) {
      return intoAsync((await call('PUT', `Backups/${id}`, values)));
    },

    async delete(id) {
      return intoAsync((await call('DELETE', `Backups/${id}`)));
    },

    async restore(values) {
      return intoAsync((await call('POST', 'Backups/Restore', values)));
    }

  };
}