"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = cloudVolumes;

var _cloudVolumes = _interopRequireDefault(require("../../service/cloud-volumes"));

var _logger = _interopRequireDefault(require("../../logger"));

var _activeDirectory = _interopRequireDefault(require("./active-directory"));

var _backups = _interopRequireDefault(require("./backups"));

var _catalog = _interopRequireDefault(require("./catalog"));

var _ipRanges = _interopRequireDefault(require("./ip-ranges"));

var _jobs = _interopRequireDefault(require("./utils/jobs"));

var _networks = _interopRequireDefault(require("./networks"));

var _regions = _interopRequireDefault(require("./regions"));

var _serviceLevels = _interopRequireDefault(require("./service-levels"));

var _snapshots = _interopRequireDefault(require("./snapshots"));

var _volumes = _interopRequireDefault(require("./volumes"));

var _zones = _interopRequireDefault(require("./zones"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Manage cloud volumes storage resources.
 *
 * @example
 *
 * import api from 'qstack-client/api/cloud-volumes';
 *
 * const conf = {
 *   apiKey: 'api-key',
 *   secretKey: 'secret-key',
 *   url: 'http://nfs.example.com',
 * };
 *
 * api(conf).volumes.list();
 */
function cloudVolumes(conf) {
  _logger.default.silly(`CloudVolumes conf=${JSON.stringify(conf)}`);

  function call(method, command, data) {
    return (0, _cloudVolumes.default)(conf, method, command, data);
  }

  return {
    activeDirectory: (0, _activeDirectory.default)(call),
    backups: (0, _backups.default)(call),
    catalog: (0, _catalog.default)(call),
    ipRanges: (0, _ipRanges.default)(call),
    jobs: (0, _jobs.default)(call),
    networks: (0, _networks.default)(call),
    regions: (0, _regions.default)(call),
    serviceLevels: (0, _serviceLevels.default)(call),
    snapshots: (0, _snapshots.default)(call),
    volumes: (0, _volumes.default)(call),
    zones: (0, _zones.default)(call)
  };
}