"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _ipRanges = _interopRequireDefault(require("./ip-ranges"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UUID_1 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc41';
const UUID_2 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc42';
const ACCOUNT_UUID = '70e9c4b1-79d9-4b99-9509-865a2df453f0';
const ACCOUNT_NAME = 'foobar';
const REGION_UUID = 'a5bc73c5-5ebb-4738-a987-d58b557bf60c';
const REGION_NAME = 'West US';
const CREATED = '2018-01-01T00:00:00.000Z';
const UPDATED = '2018-02-02T09:19:10.000Z';
const MOCK_IP_RANGES = [{
  UUID: UUID_1,
  accountName: ACCOUNT_NAME,
  accountUUID: ACCOUNT_UUID,
  startIP: '10.60.30.1',
  endIP: '10.60.30.126',
  gateway: '10.60.30.1',
  netmask: '255.255.255.0',
  regionName: REGION_NAME,
  regionUUID: REGION_UUID,
  createdAt: CREATED,
  updatedAt: UPDATED
}, {
  UUID: UUID_2,
  accountName: ACCOUNT_NAME,
  accountUUID: ACCOUNT_UUID,
  startIP: '10.60.30.127',
  endIP: '10.60.30.254',
  gateway: '10.60.30.1',
  netmask: '255.255.255.0',
  vlan: 3006,
  regionName: REGION_NAME,
  regionUUID: REGION_UUID,
  createdAt: CREATED,
  updatedAt: UPDATED
}];
const ipRangeStub = (0, _sinon.stub)();
const {
  list
} = (0, _ipRanges.default)(ipRangeStub);
ipRangeStub.withArgs('GET', `Storage/IPRanges`).resolves(MOCK_IP_RANGES);
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: UUID_1,
    ip: {
      start: '10.60.30.1',
      end: '10.60.30.126'
    },
    gateway: '10.60.30.1',
    netmask: '255.255.255.0',
    vlan: null,
    account: {
      id: ACCOUNT_UUID,
      name: ACCOUNT_NAME
    },
    region: {
      id: REGION_UUID,
      name: REGION_NAME
    },
    created: new Date(CREATED),
    updated: new Date(UPDATED)
  }, {
    id: UUID_2,
    ip: {
      start: '10.60.30.127',
      end: '10.60.30.254'
    },
    gateway: '10.60.30.1',
    netmask: '255.255.255.0',
    vlan: 3006,
    account: {
      id: ACCOUNT_UUID,
      name: ACCOUNT_NAME
    },
    region: {
      id: REGION_UUID,
      name: REGION_NAME
    },
    created: new Date(CREATED),
    updated: new Date(UPDATED)
  }]);
});