"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = snapshots;

var _jobs = require("./utils/jobs");

function into(snapshot) {
  return {
    id: snapshot.snapshotId,
    volumeId: snapshot.volumeId,
    lifeCycle: {
      state: snapshot.lifeCycleState,
      details: snapshot.lifeCycleStateDetails
    },
    name: snapshot.name,
    ownerId: snapshot.ownerId,
    region: snapshot.region,
    usedBytes: snapshot.usedBytes,
    created: new Date(snapshot.created)
  };
}

function snapshots(call) {
  function intoAsync(snapshot) {
    return {
      value: into(snapshot),

      finish(sideEffect, interval, timeout, interrupt) {
        return Promise.all(snapshot.jobs.map(job => (0, _jobs.finish)(call, job.jobId, sideEffect, interval, timeout, interrupt)));
      }

    };
  }

  return {
    async list(volumeId, id) {
      if (volumeId && id) {
        return into((await call('GET', `Volumes/${volumeId}/Snapshots/${id}`)));
      }

      if (volumeId) {
        return (await call('GET', `Volumes/${volumeId}/Snapshots`)).map(into);
      }

      if (id) {
        return into((await call('GET', `Snapshots/${id}`)));
      }

      return (await call('GET', 'Snapshots')).map(into);
    },

    async create(values) {
      return intoAsync((await call('POST', 'Snapshots', values)));
    },

    async update(id, values) {
      return intoAsync((await call('PUT', `Snapshots/${id}`, values)));
    },

    async delete(id) {
      return intoAsync((await call('DELETE', `Snapshots/${id}`)));
    }

  };
}