"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _snapshots = _interopRequireDefault(require("./snapshots"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ID_1 = 'f6c3bf7f-4ff5-265c-90b7-a1fc5e23e760';
const ID_2 = 'f6c3bf7f-4ff5-265c-90b7-a1fc5e23e761';
const JOB_ID_1 = 'job3bf7f-4ff5-265c-90b7-a1fc5e23e760';
const JOB_ID_2 = 'job3bf7f-4ff5-265c-90b7-a1fc5e23e761';
const VOLID_1 = '722f4496-a8a1-3145-544a-40d2e4f73f0f';
const OWNER_ID = '70e9c4b1-79d9-4b99-9509-865a2df453f0';
const REGION = 'West US';
const DATE_1 = '2018-02-21T00:00:04.000Z';
const DATE_2 = '2018-02-21T00:15:01.000Z';
const NAME_1 = 'daily-0-min-past-12am.2018-02-21_0000';
const NAME_2 = 'hourly-15-min-past-hour.2018-02-21_0015';
const MOCK_SNAPSHOTS = [{
  snapshotId: ID_1,
  jobs: [{
    jobId: JOB_ID_1
  }],
  volumeId: VOLID_1,
  created: DATE_1,
  lifeCycleState: 'available',
  lifeCycleStateDetails: 'Available for use',
  name: NAME_1,
  ownerId: OWNER_ID,
  region: REGION,
  usedBytes: 104
}, {
  snapshotId: ID_2,
  jobs: [{
    jobId: JOB_ID_2
  }],
  volumeId: VOLID_1,
  created: DATE_2,
  lifeCycleState: 'available',
  lifeCycleStateDetails: 'Available for use',
  name: NAME_2,
  ownerId: OWNER_ID,
  region: REGION,
  usedBytes: 96
}];
const snapshotStub = (0, _sinon.stub)();
const {
  list,
  create,
  update,
  delete: remove
} = (0, _snapshots.default)(snapshotStub);
snapshotStub.withArgs('GET', `Snapshots`).resolves(MOCK_SNAPSHOTS);
snapshotStub.withArgs('GET', `Snapshots/${ID_1}`).resolves(MOCK_SNAPSHOTS[0]);
snapshotStub.withArgs('GET', `Volumes/${VOLID_1}/Snapshots`).resolves(MOCK_SNAPSHOTS);
snapshotStub.withArgs('GET', `Volumes/${VOLID_1}/Snapshots/${ID_1}`).resolves(MOCK_SNAPSHOTS[0]);
const createStub = snapshotStub.withArgs('POST', 'Snapshots').resolves({ ...MOCK_SNAPSHOTS[0],
  name: 'Created snapshot'
});
const updateStub = snapshotStub.withArgs('PUT', `Snapshots/${ID_1}`).resolves({ ...MOCK_SNAPSHOTS[0],
  name: 'Updated snapshot'
});
snapshotStub.withArgs('DELETE', `Snapshots/${ID_1}`).resolves({ ...MOCK_SNAPSHOTS[0],
  name: 'Deleted snapshot'
});
snapshotStub.withArgs('GET', `Jobs/${JOB_ID_1}`).resolves({
  state: 'done',
  jobId: JOB_ID_1,
  objectType: 'Snapshot',
  objectId: ID_1
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: ID_1,
    volumeId: VOLID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: NAME_1,
    ownerId: OWNER_ID,
    region: REGION,
    usedBytes: 104,
    created: new Date(DATE_1)
  }, {
    id: ID_2,
    volumeId: VOLID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: NAME_2,
    ownerId: OWNER_ID,
    region: REGION,
    usedBytes: 96,
    created: new Date(DATE_2)
  }]);
});
(0, _ava.default)('list(null, id)', async t => {
  t.deepEqual((await list(null, ID_1)), {
    id: ID_1,
    volumeId: VOLID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: NAME_1,
    ownerId: OWNER_ID,
    region: REGION,
    usedBytes: 104,
    created: new Date(DATE_1)
  });
});
(0, _ava.default)('list(volumeId)', async t => {
  t.deepEqual((await list(VOLID_1)), [{
    id: ID_1,
    volumeId: VOLID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: NAME_1,
    ownerId: OWNER_ID,
    region: REGION,
    usedBytes: 104,
    created: new Date(DATE_1)
  }, {
    id: ID_2,
    volumeId: VOLID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: NAME_2,
    ownerId: OWNER_ID,
    region: REGION,
    usedBytes: 96,
    created: new Date(DATE_2)
  }]);
});
(0, _ava.default)('list(volumeId, id)', async t => {
  t.deepEqual((await list(VOLID_1, ID_1)), {
    id: ID_1,
    volumeId: VOLID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: NAME_1,
    ownerId: OWNER_ID,
    region: REGION,
    usedBytes: 104,
    created: new Date(DATE_1)
  });
});
(0, _ava.default)('create(values)', async t => {
  const snapshot = await create({
    name: 'foo'
  });
  t.deepEqual(snapshot.value, {
    id: ID_1,
    volumeId: VOLID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: 'Created snapshot',
    ownerId: OWNER_ID,
    region: REGION,
    usedBytes: 104,
    created: new Date(DATE_1)
  });
  t.deepEqual(createStub.firstCall.args[2], {
    name: 'foo'
  });
});
(0, _ava.default)('create() finish', async t => {
  const snapshot = await create({
    name: 'foo'
  });
  t.deepEqual((await snapshot.finish()), [{
    jobId: JOB_ID_1,
    state: 'done',
    objectType: 'Snapshot',
    objectId: ID_1
  }]);
});
(0, _ava.default)('update(id, values)', async t => {
  const snapshot = await update(ID_1, {
    name: 'bar'
  });
  t.is(typeof snapshot.finish, 'function');
  t.deepEqual(snapshot.value, {
    id: ID_1,
    volumeId: VOLID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: 'Updated snapshot',
    ownerId: OWNER_ID,
    region: REGION,
    usedBytes: 104,
    created: new Date(DATE_1)
  });
  t.deepEqual(updateStub.firstCall.args[2], {
    name: 'bar'
  });
});
(0, _ava.default)('update() finish', async t => {
  const snapshot = await update(ID_1, {
    name: 'bar'
  });
  t.deepEqual((await snapshot.finish()), [{
    jobId: JOB_ID_1,
    state: 'done',
    objectType: 'Snapshot',
    objectId: ID_1
  }]);
});
(0, _ava.default)('remove(id)', async t => {
  const snapshot = await remove(ID_1);
  t.deepEqual(snapshot.value, {
    id: ID_1,
    volumeId: VOLID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: 'Deleted snapshot',
    ownerId: OWNER_ID,
    region: REGION,
    usedBytes: 104,
    created: new Date(DATE_1)
  });
});
(0, _ava.default)('delete() finish', async t => {
  const snapshot = await update(ID_1);
  t.deepEqual((await snapshot.finish()), [{
    jobId: JOB_ID_1,
    state: 'done',
    objectType: 'Snapshot',
    objectId: ID_1
  }]);
});