"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.finish = finish;
exports.default = jobs;

var _error = require("../../../service/error");

const HOUR = 60 * 60 * 1000;

function sleep(ms) {
  return new Promise(resolve => {
    global.setTimeout(resolve, ms);
  });
}

// eslint-disable-next-line import/prefer-default-export
async function finish(call, jobId, sideEffect = null, interval = 500, timeout = HOUR, interrupt = null) {
  const start = Date.now();

  function getJob() {
    return call('GET', `Jobs/${jobId}`);
  }

  async function recursion(job) {
    if (job.state === 'done') {
      return job;
    }

    if (job.state === 'error') {
      throw new _error.ServiceError(500, job.stateDetails, job);
    }

    if (interrupt && (await interrupt())) {
      return job;
    }

    const elapsed = Date.now() - start;

    if (elapsed > timeout) {
      throw new _error.ServiceError(408, `job "${job.action}" for object "${job.objectType}" with id "${job.objectId}" timed out after ${Math.round(elapsed / 1000)} seconds`, job);
    }

    await Promise.all([sideEffect && sideEffect(job), sleep(interval)]);
    return recursion((await getJob()));
  }

  return recursion((await getJob()));
}

function jobs(call) {
  return {
    async get(id) {
      return call('GET', `Jobs/${id}`);
    },

    async finish(jobId, sideEffect, interval, timeout, interrupt) {
      return finish(call, jobId, sideEffect, interval || 500, timeout || HOUR, interrupt);
    }

  };
}