"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = volumes;

var _jobs = require("./utils/jobs");

function into(volume) {
  return {
    id: volume.volumeId,
    lifeCycle: {
      state: volume.lifeCycleState,
      details: volume.lifeCycleStateDetails
    },
    name: volume.name,
    ownerId: volume.ownerId,
    region: volume.region,
    creationToken: volume.creationToken,
    protocolTypes: volume.protocolTypes || null,
    quotaInBytes: volume.quotaInBytes,
    securityStyle: volume.securityStyle || null,
    serviceLevel: volume.serviceLevel,
    snapReserve: volume.snapReserve,
    snapshotDirectory: typeof volume.snapshotDirectory === 'boolean' ? volume.snapshotDirectory : true,
    timezone: volume.timezone,
    totalInodes: typeof volume.totalInodes === 'number' ? volume.totalInodes : null,
    usedBytes: volume.usedBytes,
    usedBytesBySnapshots: volume.usedBytesBySnapshots,
    usedInodes: typeof volume.usedInodes === 'number' ? volume.usedInodes : null,
    labels: volume.labels || null,
    created: new Date(volume.created),
    mountPoints: volume.mountPoints || null,
    backupPolicy: volume.backupPolicy || null,
    exportPolicy: volume.exportPolicy || null,
    snapshotPolicy: volume.snapshotPolicy || null
  };
}

function volumes(call) {
  function intoAsync(volume) {
    return {
      value: into(volume),

      finish(sideEffect, interval, timeout, interrupt) {
        return Promise.all(volume.jobs.map(job => (0, _jobs.finish)(call, job.jobId, sideEffect, interval, timeout, interrupt)));
      }

    };
  }

  return {
    async list(id) {
      if (id) {
        return into((await call('GET', `Volumes/${id}`)));
      }

      return (await call('GET', 'Volumes')).map(into);
    },

    async create(values) {
      return intoAsync((await call('POST', 'Volumes', values)));
    },

    async update(id, values) {
      return intoAsync((await call('PUT', `Volumes/${id}`, values)));
    },

    async delete(id, values) {
      return intoAsync((await call('DELETE', `Volumes/${id}`, values)));
    },

    async revert(id, snapshotId) {
      return into((await call('POST', `Volumes/${id}/Revert`, {
        snapshotId
      })));
    }

  };
}