"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _volumes = _interopRequireDefault(require("./volumes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ID_1 = '722f4496-a8a1-3145-544a-40d2e4f73f00';
const ID_2 = '722f4496-a8a1-3145-544a-40d2e4f73f01';
const JOB_ID_1 = 'jobf4496-a8a1-3145-544a-40d2e4f73f00';
const JOB_ID_2 = 'jobf4496-a8a1-3145-544a-40d2e4f73f01';
const OWNER_ID = '70e9c4b1-79d9-4b99-9509-865a2df453f0';
const QUOTA = 1099511627776;
const TIMEZONE = 'America/Los_Angeles';
const CREATION_TOKEN_1 = 'concomitant-jovial-laddi';
const CREATION_TOKEN_2 = 'concomitant-jovial-runar';
const CREATED = '2018-01-01T00:00:00.000Z';
const MOUNT_POINT = {
  server: 'server_name',
  vlanId: 1001,
  export: 'export',
  exportFull: 'exportFull',
  protocolType: 'NFSv3',
  instructions: 'instructions'
};
const MOCK_VOLUMES = [{
  volumeId: ID_1,
  jobs: [{
    jobId: JOB_ID_1
  }],
  name: 'Volume 1',
  lifeCycleState: 'available',
  lifeCycleStateDetails: 'Available for use',
  ownerId: OWNER_ID,
  region: 'West US',
  creationToken: CREATION_TOKEN_1,
  protocolTypes: ['NFSv3'],
  quotaInBytes: QUOTA,
  securityStyle: 'unix',
  serviceLevel: 'basic',
  snapReserve: 1,
  snapshotDirectory: true,
  timezone: TIMEZONE,
  totalInodes: 100,
  usedBytes: 2048,
  usedBytesBySnapshots: 0,
  usedInodes: 5,
  created: CREATED,
  labels: ['foo', 'bar'],
  mountPoints: [MOUNT_POINT]
}, {
  volumeId: ID_2,
  jobs: [{
    jobId: JOB_ID_2
  }],
  name: 'Volume 2',
  lifeCycleState: 'error',
  lifeCycleStateDetails: 'Error mounting',
  ownerId: OWNER_ID,
  region: 'West US',
  creationToken: CREATION_TOKEN_2,
  quotaInBytes: QUOTA,
  serviceLevel: 'advanced',
  snapReserve: 2,
  snapshotDirectory: false,
  timezone: TIMEZONE,
  usedBytes: 1024,
  usedBytesBySnapshots: 128,
  created: CREATED
}];
const EXPORT_POLICY = {
  rules: [{
    allowedClients: '0.0.0.0/0',
    nfsv3: true,
    nfsv4: false,
    ruleIndex: 1,
    unixReadOnly: false,
    unixReadWrite: true
  }, {
    allowedClients: '1.1.1.1/1',
    nfsv3: false,
    nfsv4: true,
    ruleIndex: 2,
    unixReadOnly: true,
    unixReadWrite: false
  }]
};
const SNAPSHOT_POLICY = {
  enabled: true,
  dailySchedule: {
    hour: 0,
    minute: 0,
    snapshotsToKeep: 3
  },
  hourlySchedule: {
    minute: 0,
    snapshotsToKeep: 0
  },
  monthlySchedule: {
    daysOfMonth: '1',
    hour: 0,
    minute: 0,
    snapshotsToKeep: 0
  },
  weeklySchedule: {
    day: 'Sunday',
    hour: 0,
    minute: 0,
    snapshotsToKeep: 0
  }
};
const BACKUP_POLICY = {
  enabled: true,
  dailyBackupsToKeep: 31,
  weeklyBackupsToKeep: 52,
  monthlyBackupsToKeep: 60
};
const volumeStub = (0, _sinon.stub)();
const {
  list,
  create,
  update,
  delete: remove
} = (0, _volumes.default)(volumeStub);
volumeStub.withArgs('GET', `Volumes`).resolves(MOCK_VOLUMES);
volumeStub.withArgs('GET', `Volumes/${ID_1}`).resolves({ ...MOCK_VOLUMES[0],
  snapshotPolicy: SNAPSHOT_POLICY,
  exportPolicy: EXPORT_POLICY,
  backupPolicy: BACKUP_POLICY
});
const createStub = volumeStub.withArgs('POST', 'Volumes').resolves({ ...MOCK_VOLUMES[0],
  name: 'Created volume',
  snapshotPolicy: SNAPSHOT_POLICY,
  exportPolicy: EXPORT_POLICY,
  backupPolicy: BACKUP_POLICY
});
const updateStub = volumeStub.withArgs('PUT', `Volumes/${ID_1}`).resolves({ ...MOCK_VOLUMES[0],
  name: 'Updated volume',
  snapshotPolicy: SNAPSHOT_POLICY,
  exportPolicy: EXPORT_POLICY,
  backupPolicy: BACKUP_POLICY
});
volumeStub.withArgs('DELETE', `Volumes/${ID_1}`).resolves({ ...MOCK_VOLUMES[0],
  name: 'Deleted volume',
  snapshotPolicy: SNAPSHOT_POLICY,
  exportPolicy: EXPORT_POLICY,
  backupPolicy: BACKUP_POLICY
});
volumeStub.withArgs('GET', `Jobs/${JOB_ID_1}`).resolves({
  state: 'done',
  jobId: JOB_ID_1,
  objectType: 'Volume',
  objectId: ID_1
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: ID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: 'Volume 1',
    ownerId: OWNER_ID,
    region: 'West US',
    creationToken: CREATION_TOKEN_1,
    protocolTypes: ['NFSv3'],
    quotaInBytes: QUOTA,
    securityStyle: 'unix',
    serviceLevel: 'basic',
    snapReserve: 1,
    snapshotDirectory: true,
    timezone: TIMEZONE,
    totalInodes: 100,
    usedBytes: 2048,
    usedBytesBySnapshots: 0,
    usedInodes: 5,
    created: new Date(CREATED),
    snapshotPolicy: null,
    exportPolicy: null,
    backupPolicy: null,
    labels: ['foo', 'bar'],
    mountPoints: [MOUNT_POINT]
  }, {
    id: ID_2,
    lifeCycle: {
      state: 'error',
      details: 'Error mounting'
    },
    name: 'Volume 2',
    ownerId: OWNER_ID,
    region: 'West US',
    creationToken: CREATION_TOKEN_2,
    protocolTypes: null,
    quotaInBytes: QUOTA,
    securityStyle: null,
    serviceLevel: 'advanced',
    snapReserve: 2,
    snapshotDirectory: false,
    timezone: TIMEZONE,
    totalInodes: null,
    usedBytes: 1024,
    usedBytesBySnapshots: 128,
    usedInodes: null,
    created: new Date(CREATED),
    snapshotPolicy: null,
    exportPolicy: null,
    backupPolicy: null,
    labels: null,
    mountPoints: null
  }]);
});
(0, _ava.default)('list(id)', async t => {
  t.deepEqual((await list(ID_1)), {
    id: ID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: 'Volume 1',
    ownerId: OWNER_ID,
    region: 'West US',
    creationToken: CREATION_TOKEN_1,
    protocolTypes: ['NFSv3'],
    quotaInBytes: QUOTA,
    securityStyle: 'unix',
    serviceLevel: 'basic',
    snapReserve: 1,
    snapshotDirectory: true,
    timezone: TIMEZONE,
    totalInodes: 100,
    usedBytes: 2048,
    usedBytesBySnapshots: 0,
    usedInodes: 5,
    created: new Date(CREATED),
    snapshotPolicy: SNAPSHOT_POLICY,
    exportPolicy: EXPORT_POLICY,
    backupPolicy: BACKUP_POLICY,
    labels: ['foo', 'bar'],
    mountPoints: [MOUNT_POINT]
  });
});
(0, _ava.default)('create(values)', async t => {
  const volume = await create({
    name: 'foo'
  });
  t.deepEqual(volume.value, {
    id: ID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: 'Created volume',
    ownerId: OWNER_ID,
    region: 'West US',
    creationToken: CREATION_TOKEN_1,
    protocolTypes: ['NFSv3'],
    quotaInBytes: QUOTA,
    securityStyle: 'unix',
    serviceLevel: 'basic',
    snapReserve: 1,
    snapshotDirectory: true,
    timezone: TIMEZONE,
    totalInodes: 100,
    usedBytes: 2048,
    usedBytesBySnapshots: 0,
    usedInodes: 5,
    created: new Date(CREATED),
    snapshotPolicy: SNAPSHOT_POLICY,
    exportPolicy: EXPORT_POLICY,
    backupPolicy: BACKUP_POLICY,
    labels: ['foo', 'bar'],
    mountPoints: [MOUNT_POINT]
  });
  t.deepEqual(createStub.firstCall.args[2], {
    name: 'foo'
  });
});
(0, _ava.default)('create() finish', async t => {
  const volume = await create({
    name: 'foo'
  });
  t.deepEqual((await volume.finish()), [{
    jobId: JOB_ID_1,
    state: 'done',
    objectType: 'Volume',
    objectId: ID_1
  }]);
});
(0, _ava.default)('update(id, values)', async t => {
  const volume = await update(ID_1, {
    name: 'bar'
  });
  t.deepEqual(volume.value, {
    id: ID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: 'Updated volume',
    ownerId: OWNER_ID,
    region: 'West US',
    creationToken: CREATION_TOKEN_1,
    protocolTypes: ['NFSv3'],
    quotaInBytes: QUOTA,
    securityStyle: 'unix',
    serviceLevel: 'basic',
    snapReserve: 1,
    snapshotDirectory: true,
    timezone: TIMEZONE,
    totalInodes: 100,
    usedBytes: 2048,
    usedBytesBySnapshots: 0,
    usedInodes: 5,
    created: new Date(CREATED),
    snapshotPolicy: SNAPSHOT_POLICY,
    exportPolicy: EXPORT_POLICY,
    backupPolicy: BACKUP_POLICY,
    labels: ['foo', 'bar'],
    mountPoints: [MOUNT_POINT]
  });
  t.deepEqual(updateStub.firstCall.args[2], {
    name: 'bar'
  });
});
(0, _ava.default)('update() finish', async t => {
  const volume = await update(ID_1, {
    name: 'bar'
  });
  t.deepEqual((await volume.finish()), [{
    jobId: JOB_ID_1,
    state: 'done',
    objectType: 'Volume',
    objectId: ID_1
  }]);
});
(0, _ava.default)('delete(id)', async t => {
  const volume = await remove(ID_1);
  t.deepEqual(volume.value, {
    id: ID_1,
    lifeCycle: {
      state: 'available',
      details: 'Available for use'
    },
    name: 'Deleted volume',
    ownerId: OWNER_ID,
    region: 'West US',
    creationToken: CREATION_TOKEN_1,
    protocolTypes: ['NFSv3'],
    quotaInBytes: QUOTA,
    securityStyle: 'unix',
    serviceLevel: 'basic',
    snapReserve: 1,
    snapshotDirectory: true,
    timezone: TIMEZONE,
    totalInodes: 100,
    usedBytes: 2048,
    usedBytesBySnapshots: 0,
    usedInodes: 5,
    created: new Date(CREATED),
    snapshotPolicy: SNAPSHOT_POLICY,
    exportPolicy: EXPORT_POLICY,
    backupPolicy: BACKUP_POLICY,
    labels: ['foo', 'bar'],
    mountPoints: [MOUNT_POINT]
  });
});
(0, _ava.default)('delete() finish', async t => {
  const volume = await remove(ID_1);
  t.deepEqual((await volume.finish()), [{
    jobId: JOB_ID_1,
    state: 'done',
    objectType: 'Volume',
    objectId: ID_1
  }]);
});