"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = networks;

/**
 * A description of a storage account.
 */

/**
 * Manage networks.
 */
function intoJob(job) {
  return {
    id: job.uuid,
    accountID: job.accountUUID,
    correlationID: job.correlationID,
    workerID: job.workerID,
    objectID: job.objectUUID,
    objectType: job.objectType,
    action: job.action,
    state: job.state,
    stateDetails: job.stateDetails,
    aborted: !!job.aborted,
    progress: job.progress,
    created: new Date(job.createdAt),
    updated: new Date(job.updatedAt)
  };
}

function into(network) {
  return {
    id: network.uuid,
    remoteAccountID: network.remoteAccountID,
    accountID: network.accountUUID,
    cidr: network.cidr,
    l3VNI: network.l3VNI,
    l2VNI: network.l2VNI,
    vrfID: network.vrfID,
    iprangeID: network.iprangeUUID,
    vlnetworks: (network.vlnetworks || []).map(({
      uuid: id,
      createdAt,
      updatedAt,
      networkUUID: networkID,
      borderSwitchUUID: borderSwitchID,
      jobs,
      ...rest
    }) => ({
      id,
      networkID,
      borderSwitchID,
      ...rest,
      jobs: (jobs || []).map(intoJob),
      created: new Date(createdAt),
      updated: new Date(updatedAt)
    })),
    vxnetworks: (network.vxnetworks || []).map(({
      uuid: id,
      createdAt,
      updatedAt,
      networkUUID: networkID,
      jobs,
      ...rest
    }) => ({
      id,
      networkID,
      ...rest,
      jobs: (jobs || []).map(intoJob),
      created: new Date(createdAt),
      updated: new Date(updatedAt)
    })),
    created: new Date(network.createdAt),
    updated: new Date(network.updatedAt)
  };
}

function networks(call) {
  return {
    async list(id) {
      if (id) {
        return into((await call('GET', `network/${id}`)));
      }

      return (await call('GET', 'network')).map(into);
    }

  };
}