"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = accounts;

/**
 * A description of a storage account.
 */

/**
 * Parameters passed in updating storage account.
 */

/**
 * Manage storage accounts.
 */
function into(account) {
  return {
    id: account.uuid,
    name: account.name,
    state: account.state,
    publicAccess: !!account.publicAccess,
    accountSettings: account.accountSettings || [],
    allowedHosts: (account.allowedHosts || []).map(({
      stampUUID: stampId,
      password,
      ...rest
    }) => ({ ...rest,
      stampId
    })),
    created: new Date(account.createdAt),
    updated: new Date(account.updatedAt),
    deleted: account.deletedAt && new Date(account.deletedAt) || null
  };
}

function accounts(call) {
  return {
    async list(id) {
      if (id) {
        return into((await call('GET', `account/${id}`)));
      }

      return (await call('GET', 'account')).map(into);
    },

    async update(id, values) {
      return into((await call('PUT', `account/${id}`, values)));
    },

    async setHosts(id, values) {
      return call('PUT', `account/${id}/hosts`, values);
    },

    async delete(id) {
      return call('DELETE', `account/${id}`);
    }

  };
}