"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _accounts = _interopRequireDefault(require("./accounts"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UUID_1 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc41';
const UUID_2 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc42';
const NAME_1 = 'foo';
const NAME_2 = 'bar';
const CREATED = '2018-01-01T00:00:00.000Z';
const UPDATED = '2018-02-02T09:19:10.000Z';
const DELETED = '2018-02-03T10:10:20.000Z';
const MOCK_ACCOUNTS = [{
  uuid: UUID_1,
  name: NAME_1,
  state: 'enabled',
  publicAccess: true,
  createdAt: CREATED,
  updatedAt: UPDATED
}, {
  uuid: UUID_2,
  name: NAME_2,
  state: 'disabled',
  publicAccess: false,
  accountSettings: [{
    type: 'type_1',
    region: 'region_1',
    value: 'value_1'
  }],
  createdAt: CREATED,
  updatedAt: UPDATED,
  deletedAt: DELETED
}];
const accountsStub = (0, _sinon.stub)();
const {
  list,
  update,
  delete: remove
} = (0, _accounts.default)(accountsStub);
accountsStub.withArgs('GET', `account`).resolves(MOCK_ACCOUNTS);
accountsStub.withArgs('GET', `account/${UUID_1}`).resolves(MOCK_ACCOUNTS[0]);
const updateStub = accountsStub.withArgs('PUT', `account/${UUID_1}`).resolves({ ...MOCK_ACCOUNTS[0],
  name: 'Updated account'
});
accountsStub.withArgs('DELETE', `account/${UUID_1}`).resolves({
  deleted: true
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: UUID_1,
    name: NAME_1,
    state: 'enabled',
    publicAccess: true,
    accountSettings: [],
    allowedHosts: [],
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  }, {
    id: UUID_2,
    name: NAME_2,
    state: 'disabled',
    publicAccess: false,
    accountSettings: [{
      type: 'type_1',
      region: 'region_1',
      value: 'value_1'
    }],
    allowedHosts: [],
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: new Date(DELETED)
  }]);
});
(0, _ava.default)('list(accountId)', async t => {
  t.deepEqual((await list(UUID_1)), {
    id: UUID_1,
    name: NAME_1,
    state: 'enabled',
    publicAccess: true,
    accountSettings: [],
    allowedHosts: [],
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
});
(0, _ava.default)('update(id, values)', async t => {
  t.deepEqual((await update(UUID_1, {
    name: 'bar'
  })), {
    id: UUID_1,
    name: 'Updated account',
    state: 'enabled',
    publicAccess: true,
    accountSettings: [],
    allowedHosts: [],
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(updateStub.firstCall.args[2], {
    name: 'bar'
  });
});
(0, _ava.default)('remove(id)', async t => {
  t.deepEqual((await remove(UUID_1)), {
    deleted: true
  });
});