"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = hosts;

/**
 * A description of a storage host.
 */

/**
 * Parameters passed when creating storage host.
 */

/**
 * Parameters passed when updating storage host.
 */

/**
 * Manage storage hosts.
 */
function into(host) {
  return {
    id: host.uuid,
    name: host.name,
    type: host.type,
    version: host.version,
    capabilities: host.capabilities,
    ipAddress: host.ipAddress,
    port: host.port,
    protocol: host.protocol,
    publicAccess: !!host.publicAccess,
    maintenanceMode: !!host.maintenanceMode,
    username: host.username,
    stamp: {
      id: host.stampUUID,
      name: host.stampName
    },
    lifeCycle: {
      state: host.state,
      details: host.stateDetails
    },
    vendorId: host.vendorID || null,
    created: new Date(host.createdAt),
    updated: new Date(host.updatedAt),
    deleted: host.deletedAt && new Date(host.deletedAt) || null
  };
}

function hosts(call) {
  return {
    async list() {
      return (await call('GET', 'host')).map(into);
    },

    async create(values) {
      return into((await call('POST', `host`, values)));
    },

    async update(id, values) {
      return into((await call('PUT', `host/${id}`, values)));
    },

    async delete(id) {
      return call('DELETE', `host/${id}`);
    }

  };
}