"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _hosts = _interopRequireDefault(require("./hosts"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UUID_1 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc41';
const UUID_2 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc42';
const NAME_1 = 'foo';
const NAME_2 = 'bar';
const CREATED = '2018-01-01T00:00:00.000Z';
const UPDATED = '2018-02-02T09:19:10.000Z';
const DELETED = '2018-02-03T10:10:20.000Z';
const MOCK_HOSTS = [{
  uuid: UUID_1,
  name: NAME_1,
  type: 'type_1',
  version: 'version_1',
  capabilities: 'capabilities_1',
  ipAddress: 'ip_address_1',
  port: 'port_1',
  protocol: 'protocol_1',
  publicAccess: true,
  maintenanceMode: false,
  username: 'username_1',
  stampUUID: 'stamp_id_1',
  stampName: 'stamp_name_1',
  state: 'available',
  stateDetails: '',
  vendorID: 'vendor_id_1',
  createdAt: CREATED,
  updatedAt: UPDATED
}, {
  uuid: UUID_2,
  name: NAME_2,
  type: 'type_2',
  version: 'version_2',
  capabilities: 'capabilities_2',
  ipAddress: 'ip_address_2',
  port: 'port_2',
  protocol: 'protocol_2',
  publicAccess: false,
  maintenanceMode: false,
  username: 'username_2',
  stampUUID: 'stamp_id_2',
  stampName: 'stamp_name_2',
  state: 'error',
  stateDetails: 'Error details',
  createdAt: CREATED,
  updatedAt: UPDATED,
  deletedAt: DELETED
}];
const hostsStub = (0, _sinon.stub)();
const {
  list,
  create,
  update,
  delete: remove
} = (0, _hosts.default)(hostsStub);
hostsStub.withArgs('GET', `host`).resolves(MOCK_HOSTS);
const createStub = hostsStub.withArgs('POST', 'host').resolves({ ...MOCK_HOSTS[0],
  name: 'Created host'
});
const updateStub = hostsStub.withArgs('PUT', `host/${UUID_1}`).resolves({ ...MOCK_HOSTS[0],
  name: 'Updated host'
});
hostsStub.withArgs('DELETE', `host/${UUID_1}`).resolves({
  deleted: true
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: UUID_1,
    name: NAME_1,
    type: 'type_1',
    version: 'version_1',
    capabilities: 'capabilities_1',
    ipAddress: 'ip_address_1',
    port: 'port_1',
    protocol: 'protocol_1',
    publicAccess: true,
    maintenanceMode: false,
    username: 'username_1',
    stamp: {
      id: 'stamp_id_1',
      name: 'stamp_name_1'
    },
    lifeCycle: {
      state: 'available',
      details: ''
    },
    vendorId: 'vendor_id_1',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  }, {
    id: UUID_2,
    name: NAME_2,
    type: 'type_2',
    version: 'version_2',
    capabilities: 'capabilities_2',
    ipAddress: 'ip_address_2',
    port: 'port_2',
    protocol: 'protocol_2',
    publicAccess: false,
    maintenanceMode: false,
    username: 'username_2',
    stamp: {
      id: 'stamp_id_2',
      name: 'stamp_name_2'
    },
    lifeCycle: {
      state: 'error',
      details: 'Error details'
    },
    vendorId: null,
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: new Date(DELETED)
  }]);
});
(0, _ava.default)('create(values)', async t => {
  t.deepEqual((await create({
    name: 'foo'
  })), {
    id: UUID_1,
    name: 'Created host',
    type: 'type_1',
    version: 'version_1',
    capabilities: 'capabilities_1',
    ipAddress: 'ip_address_1',
    port: 'port_1',
    protocol: 'protocol_1',
    publicAccess: true,
    maintenanceMode: false,
    username: 'username_1',
    stamp: {
      id: 'stamp_id_1',
      name: 'stamp_name_1'
    },
    lifeCycle: {
      state: 'available',
      details: ''
    },
    vendorId: 'vendor_id_1',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(createStub.firstCall.args[2], {
    name: 'foo'
  });
});
(0, _ava.default)('update(id, values)', async t => {
  t.deepEqual((await update(UUID_1, {
    name: 'bar'
  })), {
    id: UUID_1,
    name: 'Updated host',
    type: 'type_1',
    version: 'version_1',
    capabilities: 'capabilities_1',
    ipAddress: 'ip_address_1',
    port: 'port_1',
    protocol: 'protocol_1',
    publicAccess: true,
    maintenanceMode: false,
    username: 'username_1',
    stamp: {
      id: 'stamp_id_1',
      name: 'stamp_name_1'
    },
    lifeCycle: {
      state: 'available',
      details: ''
    },
    vendorId: 'vendor_id_1',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(updateStub.firstCall.args[2], {
    name: 'bar'
  });
});
(0, _ava.default)('remove(id)', async t => {
  t.deepEqual((await remove(UUID_1)), {
    deleted: true
  });
});