"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = storage;

var _storage = _interopRequireDefault(require("../../service/storage"));

var _logger = _interopRequireDefault(require("../../logger"));

var _accounts = _interopRequireDefault(require("./accounts"));

var _clusters = _interopRequireDefault(require("./clusters"));

var _hosts = _interopRequireDefault(require("./hosts"));

var _ipRanges = _interopRequireDefault(require("./ip-ranges"));

var _networkSwitches = _interopRequireDefault(require("./network-switches"));

var _nodes = _interopRequireDefault(require("./nodes"));

var _regions = _interopRequireDefault(require("./regions"));

var _serviceAccounts = _interopRequireDefault(require("./service-accounts"));

var _stamps = _interopRequireDefault(require("./stamps"));

var _storageVms = _interopRequireDefault(require("./storage-vms"));

var _volumes = _interopRequireDefault(require("./volumes"));

var _zones = _interopRequireDefault(require("./zones"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Manage NFS storage resources. Also know as NFS infrastructure.
 *
 * @example
 *
 * import storage from 'qstack-client/api/storage';
 *
 * const conf = {
 *   apiKey: 'api-key',
 *   secretKey: 'secret-key',
 *   url: 'http://storage.example.com',
 * };
 *
 * storage(conf).hosts.list();
 */
function storage(conf) {
  _logger.default.silly(`Storage conf=${JSON.stringify(conf)}`);

  function call(method, command, data) {
    return (0, _storage.default)(conf, method, command, data);
  }

  return {
    accounts: (0, _accounts.default)(call),
    clusters: (0, _clusters.default)(call),
    hosts: (0, _hosts.default)(call),
    ipRanges: (0, _ipRanges.default)(call),
    networkSwitches: (0, _networkSwitches.default)(call),
    nodes: (0, _nodes.default)(call),
    regions: (0, _regions.default)(call),
    serviceAccounts: (0, _serviceAccounts.default)(call),
    stamps: (0, _stamps.default)(call),
    storageVMs: (0, _storageVms.default)(call),
    volumes: (0, _volumes.default)(call),
    zones: (0, _zones.default)(call)
  };
}