"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = ipRanges;

/**
 * A description of a storage IP range.
 */

/**
 * Parameters passed when creating storage IP range.
 */

/**
 * Parameters passed when updating storage IP range.
 */

/**
 * Manage storage IP ranges.
 */
function into(ipRange) {
  return {
    id: ipRange.uuid,
    ip: {
      start: ipRange.startIP,
      end: ipRange.endIP
    },
    gateway: ipRange.gateway,
    netmask: ipRange.netmask,
    vlan: ipRange.vlanID || null,
    account: {
      id: ipRange.accountUUID,
      name: ipRange.accountName
    },
    region: {
      id: ipRange.regionUUID,
      name: ipRange.regionName
    },
    created: new Date(ipRange.createdAt),
    updated: new Date(ipRange.updatedAt),
    deleted: ipRange.deletedAt && new Date(ipRange.deletedAt) || null
  };
}

function ipRanges(call) {
  return {
    async list(id) {
      if (id) {
        return into((await call('GET', `iprange/${id}`)));
      }

      return (await call('GET', 'iprange')).map(into);
    },

    async create(values) {
      return into((await call('POST', `iprange`, values)));
    },

    async update(id, values) {
      return into((await call('PUT', `iprange/${id}`, values)));
    },

    async delete(id) {
      return call('DELETE', `iprange/${id}`);
    }

  };
}