"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _networkSwitches = _interopRequireDefault(require("./network-switches"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UUID_1 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc41';
const UUID_2 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc42';
const CLUSTER_UUID = 'a5bc73c5-5ebb-4738-a987-d58b557bf60c';
const CREATED = '2018-01-01T00:00:00.000Z';
const UPDATED = '2018-02-02T09:19:10.000Z';
const DELETED = '2018-02-03T10:10:20.000Z';
const MOCK_NETWORK_SWITCHES = [{
  uuid: UUID_1,
  name: 'name-1',
  host: '1.2.3.4',
  username: 'username-1',
  password: 'secret',
  model: 'model-1',
  osiLayer: 'osi-layer-1',
  isPrimary: true,
  clusterUUID: CLUSTER_UUID,
  caCert: 'ca-cert-1',
  createdAt: CREATED,
  updatedAt: UPDATED
}, {
  uuid: UUID_2,
  name: 'name-2',
  host: '2.3.4.5',
  username: 'username-2',
  password: 'secret',
  model: 'model-2',
  osiLayer: 'osi-layer-2',
  isPrimary: false,
  clusterUUID: CLUSTER_UUID,
  caCert: 'ca-cert-2',
  createdAt: CREATED,
  updatedAt: UPDATED,
  deletedAt: DELETED
}];
const networkSwitchStub = (0, _sinon.stub)();
const {
  list,
  create,
  update,
  delete: remove
} = (0, _networkSwitches.default)(networkSwitchStub);
networkSwitchStub.withArgs('GET', `networkswitch`).resolves(MOCK_NETWORK_SWITCHES);
const createStub = networkSwitchStub.withArgs('POST', 'networkswitch').resolves({ ...MOCK_NETWORK_SWITCHES[0],
  uuid: 'Created network switch'
});
const updateStub = networkSwitchStub.withArgs('PUT', `networkswitch/${UUID_1}`).resolves({ ...MOCK_NETWORK_SWITCHES[0],
  uuid: 'Updated network switch'
});
networkSwitchStub.withArgs('DELETE', `networkswitch/${UUID_1}`).resolves({
  deleted: true
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: UUID_1,
    name: 'name-1',
    host: '1.2.3.4',
    username: 'username-1',
    password: 'secret',
    model: 'model-1',
    osiLayer: 'osi-layer-1',
    isPrimary: true,
    clusterId: CLUSTER_UUID,
    caCert: 'ca-cert-1',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  }, {
    id: UUID_2,
    name: 'name-2',
    host: '2.3.4.5',
    username: 'username-2',
    password: 'secret',
    model: 'model-2',
    osiLayer: 'osi-layer-2',
    isPrimary: false,
    clusterId: CLUSTER_UUID,
    caCert: 'ca-cert-2',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: new Date(DELETED)
  }]);
});
(0, _ava.default)('create(values)', async t => {
  t.deepEqual((await create({
    vlanID: 'foo'
  })), {
    id: 'Created network switch',
    name: 'name-1',
    host: '1.2.3.4',
    username: 'username-1',
    password: 'secret',
    model: 'model-1',
    osiLayer: 'osi-layer-1',
    isPrimary: true,
    clusterId: CLUSTER_UUID,
    caCert: 'ca-cert-1',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(createStub.firstCall.args[2], {
    vlanID: 'foo'
  });
});
(0, _ava.default)('update(id, values)', async t => {
  t.deepEqual((await update(UUID_1, {
    vlanID: 'bar'
  })), {
    id: 'Updated network switch',
    name: 'name-1',
    host: '1.2.3.4',
    username: 'username-1',
    password: 'secret',
    model: 'model-1',
    osiLayer: 'osi-layer-1',
    isPrimary: true,
    clusterId: CLUSTER_UUID,
    caCert: 'ca-cert-1',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(updateStub.firstCall.args[2], {
    vlanID: 'bar'
  });
});
(0, _ava.default)('remove(id)', async t => {
  t.deepEqual((await remove(UUID_1)), {
    deleted: true
  });
});