"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _regions = _interopRequireDefault(require("./regions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UUID_1 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc41';
const UUID_2 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc42';
const NAME_1 = 'foo';
const NAME_2 = 'bar';
const CREATED = '2018-01-01T00:00:00.000Z';
const UPDATED = '2018-02-02T09:19:10.000Z';
const DELETED = '2018-02-03T10:10:20.000Z';
const MOCK_REGIONS = [{
  uuid: UUID_1,
  name: NAME_1,
  createdAt: CREATED,
  updatedAt: UPDATED
}, {
  uuid: UUID_2,
  name: NAME_2,
  createdAt: CREATED,
  updatedAt: UPDATED,
  deletedAt: DELETED
}];
const regionsStub = (0, _sinon.stub)();
const {
  list,
  create,
  update,
  delete: remove
} = (0, _regions.default)(regionsStub);
regionsStub.withArgs('GET', `region`).resolves(MOCK_REGIONS);
const createStub = regionsStub.withArgs('POST', 'region').resolves({ ...MOCK_REGIONS[0],
  name: 'Created region'
});
const updateStub = regionsStub.withArgs('PUT', `region/${UUID_1}`).resolves({ ...MOCK_REGIONS[0],
  name: 'Updated region'
});
regionsStub.withArgs('DELETE', `region/${UUID_1}`).resolves({
  deleted: true
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: UUID_1,
    name: NAME_1,
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  }, {
    id: UUID_2,
    name: NAME_2,
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: new Date(DELETED)
  }]);
});
(0, _ava.default)('create(values)', async t => {
  t.deepEqual((await create({
    name: 'foo'
  })), {
    id: UUID_1,
    name: 'Created region',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(createStub.firstCall.args[2], {
    name: 'foo'
  });
});
(0, _ava.default)('update(id, values)', async t => {
  t.deepEqual((await update(UUID_1, {
    name: 'bar'
  })), {
    id: UUID_1,
    name: 'Updated region',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(updateStub.firstCall.args[2], {
    name: 'bar'
  });
});
(0, _ava.default)('remove(id)', async t => {
  t.deepEqual((await remove(UUID_1)), {
    deleted: true
  });
});