"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _serviceAccounts = _interopRequireDefault(require("./service-accounts"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UUID_1 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc41';
const UUID_2 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc42';
const REGION_UUID = 'a5bc73c5-5ebb-4738-a987-d58b557bf60c';
const REGION_NAME = 'West US';
const CREATED = '2018-01-01T00:00:00.000Z';
const UPDATED = '2018-02-02T09:19:10.000Z';
const DELETED = '2018-02-03T10:10:20.000Z';
const MOCK_SERVICE_ACCOUNTS = [{
  uuid: UUID_1,
  name: 'name-1',
  hyperscaler: 'aws',
  credentials: 'secret',
  regionName: REGION_NAME,
  regionUUID: REGION_UUID,
  createdAt: CREATED,
  updatedAt: UPDATED
}, {
  uuid: UUID_2,
  name: 'name-2',
  hyperscaler: 'aws',
  credentials: 'secret',
  regionName: REGION_NAME,
  regionUUID: REGION_UUID,
  createdAt: CREATED,
  updatedAt: UPDATED,
  deletedAt: DELETED
}];
const serviceAccountStub = (0, _sinon.stub)();
const {
  list,
  create,
  update,
  delete: remove
} = (0, _serviceAccounts.default)(serviceAccountStub);
serviceAccountStub.withArgs('GET', `serviceaccount`).resolves(MOCK_SERVICE_ACCOUNTS);
const createStub = serviceAccountStub.withArgs('POST', 'serviceaccount').resolves({ ...MOCK_SERVICE_ACCOUNTS[0],
  uuid: 'Created service account'
});
const updateStub = serviceAccountStub.withArgs('PUT', `serviceaccount/${UUID_1}`).resolves({ ...MOCK_SERVICE_ACCOUNTS[0],
  uuid: 'Updated service account'
});
serviceAccountStub.withArgs('DELETE', `serviceaccount/${UUID_1}`).resolves({
  deleted: true
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: UUID_1,
    name: 'name-1',
    hyperscaler: 'aws',
    credentials: 'secret',
    region: {
      id: REGION_UUID,
      name: REGION_NAME
    },
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  }, {
    id: UUID_2,
    name: 'name-2',
    hyperscaler: 'aws',
    credentials: 'secret',
    region: {
      id: REGION_UUID,
      name: REGION_NAME
    },
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: new Date(DELETED)
  }]);
});
(0, _ava.default)('create(values)', async t => {
  t.deepEqual((await create({
    vlanID: 'foo'
  })), {
    id: 'Created service account',
    name: 'name-1',
    hyperscaler: 'aws',
    credentials: 'secret',
    region: {
      id: REGION_UUID,
      name: REGION_NAME
    },
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(createStub.firstCall.args[2], {
    vlanID: 'foo'
  });
});
(0, _ava.default)('update(id, values)', async t => {
  t.deepEqual((await update(UUID_1, {
    vlanID: 'bar'
  })), {
    id: 'Updated service account',
    name: 'name-1',
    hyperscaler: 'aws',
    credentials: 'secret',
    region: {
      id: REGION_UUID,
      name: REGION_NAME
    },
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(updateStub.firstCall.args[2], {
    vlanID: 'bar'
  });
});
(0, _ava.default)('remove(id)', async t => {
  t.deepEqual((await remove(UUID_1)), {
    deleted: true
  });
});