"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = volumes;

/**
 * A description of a storage volume.
 */

/**
 * Manage storage volumes.
 */
function into(volume) {
  return {
    id: volume.uuid,
    name: volume.name,
    vendorId: volume.vendorID,
    displayName: volume.displayName,
    serviceLevel: volume.serviceLevel,
    snapReserve: volume.snapReserve,
    quotaInBytes: volume.quotaInBytes,
    timezone: volume.timezone,
    lifeCycle: {
      state: volume.lifeCycleState,
      details: volume.lifeCycleStateDetails
    },
    account: {
      id: volume.accountUUID,
      name: volume.accountName
    },
    storageVM: {
      id: volume.svmUUID,
      name: volume.svmName
    },
    created: new Date(volume.createdAt),
    updated: new Date(volume.updatedAt),
    deleted: volume.deletedAt && new Date(volume.deletedAt) || null
  };
}

function volumes(call) {
  return {
    async list(id) {
      if (id) {
        return into((await call('GET', `volume/${id}`)));
      }

      return (await call('GET', 'volume')).map(into);
    },

    async delete(id) {
      return call('DELETE', `volume/${id}`);
    }

  };
}