"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _volumes = _interopRequireDefault(require("./volumes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UUID_1 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc41';
const UUID_2 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc42';
const NAME_1 = 'foo';
const NAME_2 = 'bar';
const CREATED = '2018-01-01T00:00:00.000Z';
const UPDATED = '2018-02-02T09:19:10.000Z';
const DELETED = '2018-02-03T10:10:20.000Z';
const MOCK_VOLUMES = [{
  uuid: UUID_1,
  name: NAME_1,
  vendorID: 'vendor_id_1',
  displayName: NAME_1,
  serviceLevel: 'service_level_1',
  snapReserve: 'snap_reserve_1',
  quotaInBytes: 'quota_in_bytes_1',
  timezone: 'timezone_1',
  lifeCycleState: 'available',
  lifeCycleStateDetails: '',
  svmUUID: 'svm_uuid_1',
  svmName: 'svm_name_1',
  accountUUID: 'account_uuid_1',
  accountName: 'account_name_1',
  createdAt: CREATED,
  updatedAt: UPDATED
}, {
  uuid: UUID_2,
  name: NAME_2,
  vendorID: 'vendor_id_2',
  displayName: NAME_2,
  serviceLevel: 'service_level_2',
  snapReserve: 'snap_reserve_2',
  quotaInBytes: 'quota_in_bytes_2',
  timezone: 'timezone_2',
  lifeCycleState: 'error',
  lifeCycleStateDetails: 'Error details',
  svmUUID: 'svm_uuid_2',
  svmName: 'svm_name_2',
  accountUUID: 'account_uuid_2',
  accountName: 'account_name_2',
  createdAt: CREATED,
  updatedAt: UPDATED,
  deletedAt: DELETED
}];
const volumesStub = (0, _sinon.stub)();
const {
  list,
  delete: remove
} = (0, _volumes.default)(volumesStub);
volumesStub.withArgs('GET', `volume`).resolves(MOCK_VOLUMES);
volumesStub.withArgs('GET', `volume/${UUID_1}`).resolves(MOCK_VOLUMES[0]);
volumesStub.withArgs('DELETE', `volume/${UUID_1}`).resolves({
  deleted: true
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: UUID_1,
    name: NAME_1,
    vendorId: 'vendor_id_1',
    displayName: NAME_1,
    serviceLevel: 'service_level_1',
    snapReserve: 'snap_reserve_1',
    quotaInBytes: 'quota_in_bytes_1',
    timezone: 'timezone_1',
    lifeCycle: {
      state: 'available',
      details: ''
    },
    storageVM: {
      id: 'svm_uuid_1',
      name: 'svm_name_1'
    },
    account: {
      id: 'account_uuid_1',
      name: 'account_name_1'
    },
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  }, {
    id: UUID_2,
    name: NAME_2,
    vendorId: 'vendor_id_2',
    displayName: NAME_2,
    serviceLevel: 'service_level_2',
    snapReserve: 'snap_reserve_2',
    quotaInBytes: 'quota_in_bytes_2',
    timezone: 'timezone_2',
    lifeCycle: {
      state: 'error',
      details: 'Error details'
    },
    storageVM: {
      id: 'svm_uuid_2',
      name: 'svm_name_2'
    },
    account: {
      id: 'account_uuid_2',
      name: 'account_name_2'
    },
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: new Date(DELETED)
  }]);
});
(0, _ava.default)('list(volumeId)', async t => {
  t.deepEqual((await list(UUID_1)), {
    id: UUID_1,
    name: NAME_1,
    vendorId: 'vendor_id_1',
    displayName: NAME_1,
    serviceLevel: 'service_level_1',
    snapReserve: 'snap_reserve_1',
    quotaInBytes: 'quota_in_bytes_1',
    timezone: 'timezone_1',
    lifeCycle: {
      state: 'available',
      details: ''
    },
    storageVM: {
      id: 'svm_uuid_1',
      name: 'svm_name_1'
    },
    account: {
      id: 'account_uuid_1',
      name: 'account_name_1'
    },
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
});
(0, _ava.default)('remove(id)', async t => {
  t.deepEqual((await remove(UUID_1)), {
    deleted: true
  });
});