"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _zones = _interopRequireDefault(require("./zones"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UUID_1 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc41';
const UUID_2 = '5b0bc699-86b5-4882-f3e9-9bc1912fbc42';
const NAME_1 = 'foo';
const NAME_2 = 'bar';
const CREATED = '2018-01-01T00:00:00.000Z';
const UPDATED = '2018-02-02T09:19:10.000Z';
const DELETED = '2018-02-03T10:10:20.000Z';
const MOCK_ZONES = [{
  uuid: UUID_1,
  name: NAME_1,
  timezone: 'timezone_1',
  regionUUID: 'region_id_1',
  regionName: 'region_name_1',
  vendorID: 'vendor_id_1',
  createdAt: CREATED,
  updatedAt: UPDATED
}, {
  uuid: UUID_2,
  name: NAME_2,
  timezone: 'timezone_2',
  regionUUID: 'region_id_2',
  regionName: 'region_name_2',
  createdAt: CREATED,
  updatedAt: UPDATED,
  deletedAt: DELETED
}];
const zonesStub = (0, _sinon.stub)();
const {
  list,
  create,
  update,
  delete: remove
} = (0, _zones.default)(zonesStub);
zonesStub.withArgs('GET', `zone`).resolves(MOCK_ZONES);
const createStub = zonesStub.withArgs('POST', 'zone').resolves({ ...MOCK_ZONES[0],
  name: 'Created zone'
});
const updateStub = zonesStub.withArgs('PUT', `zone/${UUID_1}`).resolves({ ...MOCK_ZONES[0],
  name: 'Updated zone'
});
zonesStub.withArgs('DELETE', `zone/${UUID_1}`).resolves({
  deleted: true
});
(0, _ava.default)('list()', async t => {
  t.deepEqual((await list()), [{
    id: UUID_1,
    name: NAME_1,
    timezone: 'timezone_1',
    region: {
      id: 'region_id_1',
      name: 'region_name_1'
    },
    vendorId: 'vendor_id_1',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  }, {
    id: UUID_2,
    name: NAME_2,
    timezone: 'timezone_2',
    region: {
      id: 'region_id_2',
      name: 'region_name_2'
    },
    vendorId: null,
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: new Date(DELETED)
  }]);
});
(0, _ava.default)('create(values)', async t => {
  t.deepEqual((await create({
    name: 'foo'
  })), {
    id: UUID_1,
    name: 'Created zone',
    timezone: 'timezone_1',
    region: {
      id: 'region_id_1',
      name: 'region_name_1'
    },
    vendorId: 'vendor_id_1',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(createStub.firstCall.args[2], {
    name: 'foo'
  });
});
(0, _ava.default)('update(id, values)', async t => {
  t.deepEqual((await update(UUID_1, {
    name: 'bar'
  })), {
    id: UUID_1,
    name: 'Updated zone',
    timezone: 'timezone_1',
    region: {
      id: 'region_id_1',
      name: 'region_name_1'
    },
    vendorId: 'vendor_id_1',
    created: new Date(CREATED),
    updated: new Date(UPDATED),
    deleted: null
  });
  t.deepEqual(updateStub.firstCall.args[2], {
    name: 'bar'
  });
});
(0, _ava.default)('remove(id)', async t => {
  t.deepEqual((await remove(UUID_1)), {
    deleted: true
  });
});