"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.subscriptionLink = subscriptionLink;
exports.default = subscription;

var _logger = _interopRequireDefault(require("../../logger"));

var _gleipnir = _interopRequireDefault(require("../../service/gleipnir"));

var _zuora = require("./zuora");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UpdateAction = {
  SUBSCRIBE: 0,
  UNSUBSCRIBE: 1
};

function into(sub) {
  return {
    id: sub.id,
    customerId: sub.customerId,
    productCode: sub.productCode,
    active: sub.isActive,
    supportSubscriptionId: sub.supportSubscriptionId
  };
}

function intoGetValues(response) {
  return {
    subscriptionNumber: response.subscriptionNumber,
    email: response.email,
    expiryTime: response.expiryTime,
    accountNumber: response.accountNumber,
    productCode: response.productCode
  };
}

function subscriptionLink(call) {
  async function validate(link) {
    const response = await call('GET', `subscription-link/${link}`);
    return intoGetValues(response);
  }

  async function create(data) {
    const {
      link
    } = await call('POST', `subscription-link`, {
      data
    });
    return link;
  }

  return {
    validate,
    create
  };
}

function subscription(conf) {
  _logger.default.silly(`Subscription conf=${JSON.stringify(conf)}`);

  function call(method, command, data) {
    return (0, _gleipnir.default)(conf, method, command, data);
  }

  async function get() {
    const {
      objects: [sub]
    } = await call('GET', 'subscriptions');
    return into(sub);
  }

  async function create({
    customerId,
    productCode
  }) {
    await call('POST', `subscriptions`, {
      data: {
        customer_id: customerId,
        product_code: productCode
      }
    });
    return get();
  }

  async function update({
    subscriptionNumber,
    productCode,
    action
  }) {
    const response = await call('PUT', `subscriptions/${subscriptionNumber}/${productCode}`, {
      data: {
        customer_id: subscriptionNumber,
        product_code: productCode,
        action
      }
    });
    return {
      result: response.result
    };
  }

  async function subscribe({
    subscriptionNumber,
    productCode
  }) {
    return update({
      subscriptionNumber,
      productCode,
      action: UpdateAction.SUBSCRIBE
    });
  }

  async function unsubscribe({
    subscriptionNumber,
    productCode
  }) {
    return update({
      subscriptionNumber,
      productCode,
      action: UpdateAction.UNSUBSCRIBE
    });
  }

  if (conf.legacy) {
    return (0, _zuora.gqConsoleSubscription)(conf);
  }

  return {
    get,
    create,
    link: subscriptionLink(call),
    subscribe,
    unsubscribe
  };
}