"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.gqConsoleZuoraLink = gqConsoleZuoraLink;
exports.gqConsoleSubscription = gqConsoleSubscription;

var _ = require(".");

var _gqConsole = _interopRequireDefault(require("../../service/gq-console"));

var _logger = _interopRequireDefault(require("../../logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const UpdateAction = {
  Cancelled: 'Cancelled',
  Active: 'Active',
  Expired: 'Expired'
};
/**
 * CRUD for zuora's subscription Link
 */

function legacyInto(sub) {
  return {
    id: sub.id,
    customerId: sub.customer_id,
    productCode: sub.product_code,
    active: sub.is_active,
    supportSubscriptionId: sub.support_subscription_id
  };
}

function intoGetValues(response) {
  return {
    subscriptionNumber: response.subscriptionNumber,
    email: response.email,
    expiryTime: response.expiryTime,
    accountNumber: response.accountNumber,
    productCode: response.productCode
  };
}

function gqConsoleZuoraLink(call) {
  async function validate(link) {
    const response = await call('GET', `zuora-subscription-link/${link}`);
    return intoGetValues(response);
  }

  async function create(data) {
    const {
      subscriptionLink
    } = await call('POST', `zuora-subscription-link`, {
      data
    });
    return subscriptionLink;
  }

  return {
    validate,
    create
  };
}

function gqConsoleSubscription(conf) {
  _logger.default.silly(`Legacy subscription conf=${JSON.stringify(conf)}`);

  function call(method, command, data) {
    return (0, _gqConsole.default)(conf, method, command, data);
  }

  async function get() {
    const {
      objects: [sub]
    } = await call('GET', 'aws-marketplace');
    return legacyInto(sub);
  }

  async function create({
    customerId,
    productCode
  }) {
    await call('POST', `aws-marketplace`, {
      data: {
        customer_id: customerId,
        product_code: productCode
      }
    });
    return get();
  }

  async function update({
    subscriptionNumber,
    productCode,
    action
  }) {
    const response = await call('PUT', `aws-marketplace/update-zuora-subscription`, {
      data: {
        customer_id: subscriptionNumber,
        product_code: productCode,
        action
      }
    });
    return {
      result: response.result
    };
  }

  async function subscribe({
    subscriptionNumber,
    productCode
  }) {
    return update({
      subscriptionNumber,
      productCode,
      action: UpdateAction.Active
    });
  }

  async function unsubscribe({
    subscriptionNumber,
    productCode
  }) {
    return update({
      subscriptionNumber,
      productCode,
      action: UpdateAction.Cancelled
    });
  }

  return {
    get,
    create,
    link: gqConsoleZuoraLink(call),
    subscribe,
    unsubscribe
  };
}