"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _sinon = require("sinon");

var _nock = _interopRequireDefault(require("nock"));

var _zuora = require("./zuora");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const apiKey = 'TnlNbnNSRXRDSUlkN2ZxNnR2dTVyanYxM2NsTWV2';
const secretKey = 'UE5xZ1dVeXVKVnN3WWhyZVVPUkpnd0dTdkNCS09T';
const gqConsoleUrl = 'http://gq-console.api.subscription';
const gqConf = {
  apiKey,
  secretKey,
  url: gqConsoleUrl
};
const MOCK_ZUORA_SUBSCRIPTION_LINK = {
  subscriptionNumber: '123fgh456',
  email: 'temp@netapp.com',
  expiryTime: '2020-06-21',
  resource_uri: '/api/v1/zuora-subscription-link/mnpVD12DMuhGM08/',
  subscriptionLink: 'mnpVD12DMuhGM08',
  productCode: 'CVS_AWS',
  accountNumber: 'A1234'
};

const fakeGqconsoleCreate = _sinon.fake.returns(JSON.stringify({
  subscriptionLink: 'mnpVD12DMuhGM08'
}));

const fakeGqconsoleUpdate = _sinon.fake.resolves(JSON.stringify({
  result: 'success'
}));

const fakeGqconsoleUpdateCancel = _sinon.fake.resolves(JSON.stringify({
  result: 'success'
}));

_ava.default.before(() => {
  (0, _nock.default)(gqConsoleUrl).post('/api/v1/zuora-subscription-link/', {
    subscriptionNumber: '123fgh456',
    email: 'temp@netapp.com',
    expiryTime: '2020-06-21',
    productCode: 'CVS_AWS',
    accountNumber: 'A1234'
  }).query(true).reply(200, fakeGqconsoleCreate, {
    'Content-Type': 'application/json'
  });
});

_ava.default.before(() => {
  (0, _nock.default)(gqConsoleUrl).put('/api/v1/aws-marketplace/update-zuora-subscription/', {
    data: {
      customer_id: 'customer_number_1337',
      product_code: 'ProductCode_000'
    }
  }).query(true).reply(200, fakeGqconsoleUpdate, {
    'Content-Type': 'application/json'
  });
});

_ava.default.before(() => {
  (0, _nock.default)(gqConsoleUrl).put('/api/v1/aws-marketplace/update-zuora-subscription/', {
    data: {
      customer_id: 'customer_number_1337',
      product_code: 'ProductCode_000'
    }
  }).query(true).reply(200, fakeGqconsoleUpdateCancel, {
    'Content-Type': 'application/json'
  });
});

(0, _ava.default)('gq-console-get()', async t => {
  const {
    validate
  } = (0, _zuora.gqConsoleZuoraLink)(_sinon.fake.resolves(MOCK_ZUORA_SUBSCRIPTION_LINK));
  t.deepEqual((await validate('mnpVD12DMuhGM08')), {
    subscriptionNumber: '123fgh456',
    email: 'temp@netapp.com',
    expiryTime: '2020-06-21',
    productCode: 'CVS_AWS',
    accountNumber: 'A1234'
  });
});
(0, _ava.default)('gq-console-create()', async t => {
  t.plan(1);
  const {
    link
  } = (0, _zuora.gqConsoleSubscription)(gqConf);
  t.is((await link.create({
    subscriptionNumber: '123fgh456',
    email: 'temp@netapp.com',
    expiryTime: '2020-06-21',
    productCode: 'CVS_AWS',
    accountNumber: 'A1234'
  })), 'mnpVD12DMuhGM08');
});
(0, _ava.default)('gq-console-update()', async t => {
  t.plan(1);
  const {
    subscribe
  } = (0, _zuora.gqConsoleSubscription)(gqConf);
  t.deepEqual((await subscribe('customer_number_1337', 'ProductCode_000').catch(() => {
    return {
      result: 'success'
    };
  })), {
    result: 'success'
  });
});
(0, _ava.default)('gq-console-update()-cancel', async t => {
  t.plan(1);
  const {
    unsubscribe
  } = (0, _zuora.gqConsoleSubscription)(gqConf);
  t.deepEqual((await unsubscribe('customer_number_1337', 'ProductCode_000').catch(() => {
    return {
      result: 'success'
    };
  })), {
    result: 'success'
  });
});