"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRequest = getRequest;
exports.handleResponse = handleResponse;
exports.default = callCloudSync;

var _abortController = _interopRequireDefault(require("abort-controller"));

var _url = require("url");

var _nodeFetch = _interopRequireWildcard(require("node-fetch"));

var _logger = _interopRequireDefault(require("../../logger"));

var _error = require("../error");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getRequest(conf, method, command, data, params) {
  const url = new _url.URL(conf.url);
  const headers = new _nodeFetch.Headers();
  const init = {
    method,
    headers
  };

  if (conf.timeout) {
    const controller = new _abortController.default();
    init.signal = controller.signal;
    setTimeout(() => controller.abort(), conf.timeout);
  }

  if (params) {
    Object.entries(params).sort().forEach(([key, value]) => {
      if (typeof value !== 'string') {
        return;
      }

      url.searchParams.append(key, value);
    });
  }

  url.pathname = `/api/${command}`;

  _logger.default.silly(url.href);

  headers.append('Accept', 'application/json');
  headers.append('Authorization', `Bearer ${conf.token}`);
  headers.append('Connection', 'keep-alive');
  headers.append('Content-Type', 'application/json');
  headers.append('x-netapp-on-behalf', `Bearer ${conf.onbehalfToken}`);

  _logger.default.debug(`CloudSync href=${url.href}`);

  init.body = JSON.stringify(data); // $FlowFixMe

  return new _nodeFetch.Request(url.href, init);
}

async function handleResponse(response, {
  metrics,
  method,
  command,
  start
} = {}) {
  _logger.default.silly(`CloudSync response=${JSON.stringify(response)}`);

  if (metrics) {
    metrics.histogram.labels(response.status, method, command.split('/').filter(segment => !segment.match(/^[a-fA-F0-9]+$/g)).join('/')).observe(Date.now() - start);
  }

  let result;

  try {
    result = await response.json();
  } catch (e) {// Not json, for some reason
  }

  if (!response.ok) {
    const message = result && result.message || response.statusText;
    throw new _error.ServiceError(response.status, message, result);
  }

  return result || {};
}

function callCloudSync(conf, method, command, data, params) {
  _logger.default.debug(`CloudSync method=${method}`);

  _logger.default.debug(`CloudSync command=${command}`); // $FlowFixMe


  _logger.default.debug(`CloudSync data=${JSON.stringify(data)}`); // $FlowFixMe


  _logger.default.debug(`CloudSync params=${JSON.stringify(params)}`);

  const start = Date.now();
  const request = getRequest(conf, method, command, data, params);
  return (0, _nodeFetch.default)(request).then(result => handleResponse(result, {
    metrics: conf.metrics,
    method,
    command,
    start
  })).catch(e => {
    if (e.type === 'aborted') {
      throw new _error.ServiceError(408, `Request timeout: Timed out after ${conf.timeout || ''} milliseconds`, e);
    }

    throw e;
  });
}