"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRequest = getRequest;
exports.handleResponse = handleResponse;
exports.default = callCloudVolumes;

var _abortController = _interopRequireDefault(require("abort-controller"));

var _url = require("url");

var _nodeFetch = _interopRequireWildcard(require("node-fetch"));

var _logger = _interopRequireDefault(require("../../logger"));

var _error = require("../error");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getRequest(conf, method, command, data) {
  const url = new _url.URL(conf.url);
  url.pathname = `/v2/${command}`;

  _logger.default.silly(url.href);

  const headers = new _nodeFetch.Headers();
  const init = {
    method,
    headers
  };

  if (conf.timeout) {
    const controller = new _abortController.default();
    init.signal = controller.signal;
    setTimeout(() => controller.abort(), conf.timeout);
  }

  headers.append('Accept', 'application/json');
  headers.append('Content-Type', 'application/json');
  headers.append('Api-Key', conf.apiKey);
  headers.append('Secret-Key', conf.secretKey);
  init.body = JSON.stringify(data); // $FlowFixMe

  return new _nodeFetch.Request(url.href, init);
}

async function handleResponse(response, {
  metrics,
  method,
  command,
  start
} = {}) {
  _logger.default.silly(`CloudVolumes response=${JSON.stringify(response)}`);

  const contentType = response.headers.get('content-type');

  if (metrics) {
    metrics.histogram.labels(response.status, method, command.split('/').filter(segment => !segment.match(/[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}/)).join('/')).observe(Date.now() - start);
  }

  if (!contentType || !contentType.includes('application/json')) {
    let message = 'Unable to process response: ';

    if (contentType) {
      message += `Expected content-type "application/json", proxy returned "${contentType}"`;
    } else {
      message += 'Missing response header "Content-Type"';
    }

    const text = await response.text();

    _logger.default.debug(text);

    throw new _error.ServiceError(400, message, text);
  }

  if (!response.ok) {
    const details = await response.json();

    _logger.default.debug(details);

    throw new _error.ServiceError(response.status, details && details.message || response.statusText, details);
  }

  const result = await response.json();

  _logger.default.debug(result);

  return result;
}

function callCloudVolumes(conf, method, command, data) {
  _logger.default.debug(`CloudVolumes method=${method}`);

  _logger.default.debug(`CloudVolumes command=${command}`); // $FlowFixMe


  _logger.default.debug(`CloudVolumes data=${JSON.stringify(data)}`);

  const start = Date.now();
  const request = getRequest(conf, method, command, data);
  return (0, _nodeFetch.default)(request).then(result => handleResponse(result, {
    metrics: conf.metrics,
    method,
    command,
    start
  })).catch(e => {
    if (e.type === 'aborted') {
      throw new _error.ServiceError(408, `Request timeout: Timed out after ${conf.timeout || ''} milliseconds`, e);
    }

    throw e;
  });
}