#!/usr/bin/env node

const badgeUp = require('badge-up');
const fs = require('fs');
const path = require('path');
const { promisify } = require('util');

// eslint-disable-next-line import/no-unresolved
const { percent, threshold } = require('../flow-coverage/flow-coverage.json');

const badge = promisify(badgeUp);
const writeFile = promisify(fs.writeFile);

async function main() {
  const difference = percent - threshold;

  let color;

  if (difference < -40) {
    color = 'red';
  } else if (difference < -30) {
    color = 'orange';
  } else if (difference < -20) {
    color = 'yellow';
  } else if (difference < -10) {
    color = 'yellowgreen';
  } else if (difference < 0) {
    color = 'green';
  } else {
    color = 'brightgreen';
  }

  const outputPath = path.join(
    process.cwd(),
    'flow-coverage',
    'flow-coverage.svg',
  );
  const svg = await badge('flow', `${percent}%`, badgeUp.colors[color]);

  await writeFile(outputPath, svg);

  return outputPath;
}

main()
  .then(outputPath => {
    // eslint-disable-next-line no-console
    console.log(`Wrote svg badge to ${outputPath}`);
  })
  .catch(error => {
    // eslint-disable-next-line no-console
    console.error(`Unable to save flow-coverage badge: ${error}`);
    process.exit(1);
  });
